#!/usr/bin/ksh

###########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T10
#
# (C) Copyright IBM Corp. 2003,2009. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###########################################################################

# TITLE:      set_ntcdma.ksh
#
# ABSTRACT:   This script is used to setup for all Nortel options
#             specified in the config file
#
# USAGE:      set_ntcdma.ksh <config_file>
#
# FUNCTION:   For each data collection specified in nortel cdma config_file,
#             this script will create the following:
#             data directories
#             log directories
#             icf configuration file
#             icf checkpoint file
#             DA monitor file
#             Password lookup file
#             And one cron file in the ${FLEXDAHOME}/cfg directory
#
# $Header: /nfs/kl/gateways/da/CVSROOT/modules/NORTEL/scripts/set_ntcdma.ksh,v 1.10 2008/02/29 10:24:30 c-zafarr Exp $
#
################################################################################

################################################################################
# Display usage message
################################################################################
usage()
{
    echo "Usage: ${cmd} <config_file>"
    echo "     <config_file> is the nortel cdma configuration file"
    exit 1
}


################################################################################
# Create and prompts file creation
################################################################################
create_file()
{
	typeset fd=$1
    typeset file=$2
	action="Creating"

    if [ -f $file ]
    then
		test -d $SAVEDIR || mkdir -p $SAVEDIR
		cp $file $SAVEDIR
		action="Modifying"
    fi

    if [ $fd -gt 3 ]
    then
	# This results to an IO malfunction
	# fcmd="exec $fd>$file"
	# eval $cmd
	# This one works but not pretty!
	case $fd in
	    3) exec 3>$file;;
	    4) exec 4>$file;;
	    5) exec 5>$file;;
	    6) exec 6>$file;;
	    7) exec 7>$file;;
	    8) exec 8>$file;;
	    9) exec 9>$file;;
	esac
    fi

    echo "${cmd}: ${action} $(basename $file) file"
}


################################################################################
# Prints ICF common information
################################################################################
print_common_icf()
{
    typeset fd=${1:-1}
    typeset title=${2:-"FlexDA ICF Configuration File"}
    typeset -l market=${3:-"goodmarket"}
    typeset -l netype=${4:-"netype"}
    typeset -l neid=${5:-"neid"}
    typeset -l dtype=${6:-"dtype"}
    typeset -l direct=${7:-"dist"}
    typeset -l rmtcmprs=${8:-"n"}
    typeset -l concaton=${9:-"n"}

    print -u$fd "#"
    print -u$fd "# TITLE:   $title"
    print -u$fd "#"
    print -u$fd "# SITE:    $FLEXDASITE"
    print -u$fd "#"
    print -u$fd "# HOST:    $HOST"
    print -u$fd "#"
    print -u$fd "#"
    print -u$fd "# ICF_CHAT Variables:"
    print -u$fd "#"
    print -u$fd "#    ICFBIN        Location of ICF binaries."
    print -u$fd "#    ICFSCRIPT     Location of ICF scripts."
    print -u$fd "#    ICFTABLE      Filename of ICF checkpoint table."
    print -u$fd "#    ICFAPP        Filename of ICF application."
    print -u$fd "#"
    print -u$fd ""
    print -u$fd "set MARKET         \"$market\""
    print -u$fd "set NETYPE         \"$netype\""
    print -u$fd "set NEID           \"$neid\""
    print -u$fd "set DTYPE          \"$dtype\""
    print -u$fd "set DIRECT         \"$direct\""
    print -u$fd 'set TARGET         "$NETYPE$NEID.$DTYPE.$DIRECT"'
    print -u$fd ""
    print -u$fd 'set ICFBIN         "$env(FLEXDAHOME)/bin"'
    print -u$fd 'set ICFSCRIPT      "$env(FLEXDAHOME)/scripts"'
    print -u$fd 'set ICFCFG         "$env(FLEXDAHOME)/cfg"'
    print -u$fd 'set ICFTABLE       "$env(FLEXDAHOME)/log/$MARKET.$TARGET.chk"'

    if [ "$netype" == "pdsn" ] &&
       ([ "$dtype" == "faom" ] ||
        [ "$dtype" == "haom" ])
    then
        print -u$fd 'set ICFAPP         "$ICFSCRIPT/pdsnomdist.exp"'
    elif [ "$netype" == "rnc" ] &&
         [ "$dtype" == "om" ] &&
         [ "$concaton" == "y" ]
    then
        print -u$fd 'set ICFAPP         "$ICFSCRIPT/rncomdist_concat.exp"'
    elif [ "$netype" == "rnc" ] &&
         [ "$dtype" == "om" ] &&
	 [ "$rmtcmprs" == "y" ]
    then
        print -u$fd 'set ICFAPP         "$ICFSCRIPT/rncomdist_rmt.exp"'
    elif [ "$netype" == "rnc" ] &&
         [ "$dtype" == "cfg" ] &&
         [ "$concaton" == "y" ] 
    then
        print -u$fd 'set ICFAPP         "$ICFSCRIPT/rnccfgdist_concat.exp"'
    else
        print -u$fd 'set ICFAPP         "$ICFSCRIPT/$NETYPE$DTYPE$DIRECT.exp"'
    fi

    print -u$fd ""
}


################################################################################
# Prints ICF's targethost/destination information
################################################################################
print_thost_icf()
{
    typeset fd=${1:-1}
    typeset tip=${2:-tip}
    typeset tuser=${3:-tuser}
    typeset tpswd=${4:-tpswd}
    typeset tdir=${5:-tdir}

    print -u$fd "#"
    print -u$fd "# Target Prospect Server Variables"
    print -u$fd "#"
    print -u$fd "#    FLEXPMHOST    Address of Prospect server"
    print -u$fd "#    FLEXUSER      User account on Prospect server"
    print -u$fd "#    FLEXPSWD      User password on Prospect server"
    print -u$fd "#    FLEXDIR       Prospect server dist destination directory"
    print -u$fd ""
    print -u$fd "set FLEXPMHOST     \"$tip\""
    print -u$fd "set FLEXUSER       \"$tuser\""
    print -u$fd "set FLEXPSWD       {$tpswd}"
    print -u$fd "set FLEXDIR        \"$tdir\""
    print -u$fd ""
}


################################################################################
# Prints bsmcfg icf
################################################################################
print_bsmcfg_icf()
{
    typeset fd=${1:-1}
    typeset ip=${2:-ip}
    typeset user=${3:-user}
    typeset pswd=${4:-pswd}
    typeset srcid=${5:-bsmname}
    typeset srcdir=${6:-bsmcfgdir}
    typeset mtxid=${7:-mtxid}
    typeset bsmid=${8:-bsmid}
    typeset tmadj=${9:-0}
    typeset secureretrieve=${10:-1}    
    typeset securedeliver=${11:-1}
    typeset passwordauth=${12:-N}
    typeset ndays=${13:-2}

    print -u$fd "#"
    print -u$fd "# Application Variables:"
    print -u$fd "#"
    print -u$fd "#    ICFBEHIND      Number of minutes to delay an interval"
    print -u$fd "#    REMOTEHOST     Variable needed by icf_chat.exp same as BSMIP"
    print -u$fd "#    BSMIP          BSM IP address"
    print -u$fd "#    BSMNAME        BSM Name"
    print -u$fd "#    BSMUSER        Login account user for BSM"
    print -u$fd "#    BSMPSWD        Login account password for BSM. Use single quotes ' ' to"
    print -u$fd "#                   enclose password containing characters such as $; i.e 'Pa\$\$w0rd'"
    print -u$fd "#    BSMCFGDIR      BSM config data directory"
    print -u$fd "#    MTXNAME        MTX Name"
    print -u$fd "#    BSMID          BSM Id"
    print -u$fd "#    SECURERETRIEVE Use normal ftp (0) or scp (1) when retrieving files"
    print -u$fd "#    SECUREDELIVER  Use normal ftp (0) or scp (1) when transferring files to Prospect server"
    print -u$fd "#    PSWD_AUTH      Allow password-based authentication for ssh connection (Y/N)"
    print -u$fd "#                   Will be used only if SECURERETRIEVE/SECUREDELIVER is set to 1"    
    print -u$fd "#"
    print -u$fd "#    LOCALDIR       Local directory for the collected data"
    print -u$fd "#    NDAYS          Number of days to keep files in FlexDA server"
    print -u$fd ""
    print -u$fd "set ICFBEHIND      \"$tmadj\""
    print -u$fd "set REMOTEHOST     \"$ip\""
    print -u$fd "set BSMIP          \"$ip\""
    print -u$fd "set BSMNAME        \"$srcid\""
    print -u$fd "set BSMUSER        \"$user\""
    print -u$fd "set BSMPSWD        \"\$env(\$MARKET.\$NEID\_passwd)\""
    print -u$fd "set BSMCFGDIR      \"$srcdir\""
    print -u$fd "set MTXNAME        \"$mtxid\""
    print -u$fd "set BSMID          \"$bsmid\""
    print -u$fd "set SECURERETRIEVE \"$secureretrieve\""
    print -u$fd "set SECUREDELIVER  \"$securedeliver\""
    print -u$fd "set PSWD_AUTH      \"$passwordauth\""    
    print -u$fd ""
    print -u$fd "# Default source filename format"
    print -u$fd "# set SRCFILENAME  \"bsmci_dataaudit.batch.\%m\%d\%y\""
    print -u$fd ""
    print -u$fd 'set LOCALDIR       "$env(FLEXDAHOME)/data/${MARKET}_${NETYPE}${NEID}/${DTYPE}"'
    print -u$fd "set NDAYS          \"$ndays\""
    print -u$fd ""
}


################################################################################
# Prints bsmmap icf
################################################################################
print_bsmmap_icf()
{
    typeset fd=${1:-1}
    typeset ip=${2:-ip}
    typeset user=${3:-user}
    typeset pswd=${4:-pswd}
    typeset srcid=${5:-id}
    typeset mtxid=${6:-mtxid}
    typeset bsmid=${7:-bsmid}
    typeset tmadj=${8:-0}
    typeset secureretrieve=${9:-1}    
    typeset securedeliver=${10:-1}
    typeset passwordauth=${11:-N}
    typeset ndays=${12:-2}

    print -u$fd "#"
    print -u$fd "# Application Variables:"
    print -u$fd "#"
    print -u$fd "#    ICFBEHIND      Number of minutes to delay an interval"
    print -u$fd "#    REMOTEHOST     Variable needed by icf_chat.exp same as BSMIP"
    print -u$fd "#    BSMIP          BSM IP address"
    print -u$fd "#    BSMNAME        BSM Name"
    print -u$fd "#    BSMUSER        Login account user for BSM"
    print -u$fd "#    BSMPSWD        Login account password for BSM. Use single quotes ' ' to"
    print -u$fd "#                   enclose password containing characters such as $; i.e 'Pa\$\$w0rd'"    
    print -u$fd "#    MTXNAME        MTX Name"
    print -u$fd "#    BSMID          BSM Id"
    print -u$fd "#    SECURERETRIEVE Use normal ftp (0) or scp (1) when retrieving files"
    print -u$fd "#    SECUREDELIVER  Use normal ftp (0) or scp (1) when transferring files to Prospect server"
    print -u$fd "#    PSWD_AUTH      Allow password-based authentication for ssh connection (Y/N)"
    print -u$fd "#                   Will be used only if SECURERETRIEVE/SECUREDELIVER is set to 1"    
    print -u$fd "#"
    print -u$fd "#    LOCALDIR       Local directory for the collected data"
    print -u$fd "#    NDAYS          Number of days to keep files in FlexDA server"
    print -u$fd ""
    print -u$fd "set ICFBEHIND      \"$tmadj\""
    print -u$fd "set REMOTEHOST     \"$ip\""
    print -u$fd "set BSMIP          \"$ip\""
    print -u$fd "set BSMNAME        \"$srcid\""
    print -u$fd "set BSMUSER        \"$user\""
    print -u$fd "set BSMPSWD        \"\$env(\$MARKET.\$NEID\_passwd)\""
    print -u$fd "set MTXNAME        \"$mtxid\""
    print -u$fd "set BSMID          \"$bsmid\""
    print -u$fd "set SECURERETRIEVE \"$secureretrieve\""
    print -u$fd "set SECUREDELIVER  \"$securedeliver\""
    print -u$fd "set PSWD_AUTH      \"$passwordauth\""    
    print -u$fd ""
    print -u$fd 'set LOCALDIR       "$env(FLEXDAHOME)/data/${MARKET}_${NETYPE}${NEID}/${DTYPE}"'
    print -u$fd "set NDAYS          \"$ndays\""
    print -u$fd ""
}


################################################################################
# Prints bsmom icf
################################################################################
print_bsmom_icf()
{
    typeset fd=${1:-1}
    typeset ip=${2:-ip}
    typeset user=${3:-user}
    typeset pswd=${4:-pswd}
    typeset srcid=${5:-id}
    typeset srcdir=${6:-dir}
    typeset cpdsdir=${7:-dir}
    typeset mtxid=${8:-mtxid}
    typeset bsmid=${9:-bsmid}
    typeset fname=${10:-MCBTSSubsystem}
    typeset tmadj=${11:-0}
    typeset secureretrieve=${12:-1}    
    typeset securedeliver=${13:-1}
    typeset passwordauth=${14:-N}
    typeset ndays=${15:-2}
    set -A fname `echo ${fname} | tr "," " "`

    print -u$fd "#"
    print -u$fd "# Application Variables:"
    print -u$fd "#"
    print -u$fd "#    ICFBEHIND      Number of minutes to delay an interval"
    print -u$fd "#    REMOTEHOST     Variable needed by icf_chat.exp same as BSMIP"
    print -u$fd "#    BSMIP          BSM IP address"
    print -u$fd "#    BSMNAME        BSM Name"
    print -u$fd "#    BSMUSER        Login account user for BSM"
    print -u$fd "#    BSMPSWD        Login account password for BSM. Use single quotes ' ' to"
    print -u$fd "#                   enclose password containing characters such as $; i.e 'Pa\$\$w0rd'"
    print -u$fd "#    BSMOMDIR       BSM OM data directory"
    print -u$fd "#    FILENAME       BSM OM data file name"
    print -u$fd "#    MTXNAME        MTX Name"
    print -u$fd "#    BSMID          BSM Id"
    print -u$fd "#    SECURERETRIEVE Use normal ftp (0) or scp (1) when retrieving files"
    print -u$fd "#    SECUREDELIVER  Use normal ftp (0) or scp (1) when transferring files to Prospect server"    
    print -u$fd "#    PSWD_AUTH      Allow password-based authentication for ssh connection (Y/N)"
    print -u$fd "#                   Will be used only if SECURERETRIEVE/SECUREDELIVER is set to 1"    
    print -u$fd "#"
    print -u$fd "#    LOCALDIR       Local directory for the collected data"
    print -u$fd "#    NDAYS          Number of days to keep files in FlexDA server"
    print -u$fd ""
    print -u$fd "set ICFBEHIND      \"$tmadj\""
    print -u$fd "set REMOTEHOST     \"$ip\""
    print -u$fd "set BSMIP          \"$ip\""
    print -u$fd "set BSMNAME        \"$srcid\""
    print -u$fd "set BSMUSER        \"$user\""
    print -u$fd "set BSMPSWD        \"\$env(\$MARKET.\$NEID\_passwd)\""

    typeset i=0
    while (($i < ${#fname[*]}))
    do
	d=$srcdir
        if [ ${fname[$i]} == "CPDSSubsystem" ]; then d="$cpdsdir"; fi

	print -u$fd "set FILENAME(${i})    \"${fname[$i]}\""
	print -u$fd "set BSMOMDIR(${i})    \"$d\""
	((i=i+1))
    done

    print -u$fd "set MTXNAME        \"$mtxid\""
    print -u$fd "set BSMID          \"$bsmid\""
    print -u$fd "set SECURERETRIEVE \"$secureretrieve\""
    print -u$fd "set SECUREDELIVER  \"$securedeliver\""
    print -u$fd "set PSWD_AUTH      \"$passwordauth\""    
    print -u$fd ""
    print -u$fd 'set LOCALDIR       "$env(FLEXDAHOME)/data/${MARKET}_${NETYPE}${NEID}/${DTYPE}"'
    print -u$fd "set NDAYS          \"$ndays\""
    print -u$fd ""
    unset fnames
}


################################################################################
# Prints bsm tracker icf
################################################################################
print_bsmtrkr_icf()
{
    typeset fd=${1:-1}
    typeset ip=${2:-ip}
    typeset user=${3:-user}
    typeset pswd=${4:-pswd}
    typeset srcid=${5:-id}
    typeset srcdir=${6:-srdir}
    typeset bsmid=${7:-bsmid}
    typeset mtxid=${8:-mtxid}
    typeset tmadj=${9:-0}
    typeset secureretrieve=${10:-1}    
    typeset securedeliver=${11:-1}
    typeset passwordauth=${12:-N}    
    typeset ndays=${13:-2}

    print -u$fd "#"
    print -u$fd "# Application Variables:"
    print -u$fd "#"
    print -u$fd "#    ICFSNAP        Enable snapshot mode"
    print -u$fd "#    ICFBEHIND      Number of minutes to delay an interval"
    print -u$fd "#    REMOTEHOST     Variable needed by icf_chat.exp same as BSMIP"
    print -u$fd "#    BSMIP          BSM IP address"
    print -u$fd "#    BSMNAME        BSM Name"
    print -u$fd "#    BSMUSER        Login account user for BSM"
    print -u$fd "#    BSMPSWD        Login account password for BSM. Use single quotes ' ' to"
    print -u$fd "#                   enclose password containing characters such as $; i.e 'Pa\$\$w0rd'"
    print -u$fd "#    BSMSRCDIR      BSM Tracker data directory"
    print -u$fd "#    BSMID          BSM Id"
    print -u$fd "#    SECURERETRIEVE Use normal ftp (0) or scp (1) when retrieving files"
    print -u$fd "#    SECUREDELIVER  Use normal ftp (0) or scp (1) when transferring files to Prospect server"    
    print -u$fd "#    PSWD_AUTH      Allow password-based authentication for ssh connection (Y/N)"
    print -u$fd "#                   Will be used only if SECURERETRIEVE/SECUREDELIVER is set to 1"    
    print -u$fd "#"
    print -u$fd "#    LOCALDIR       Local directory for the collected data"
    print -u$fd "#    NDAYS          Number of days to keep files in FlexDA server"
    print -u$fd ""
    print -u$fd "set ICFSNAP        \"1\""
    print -u$fd "set ICFBEHIND      \"$tmadj\""
    print -u$fd "set REMOTEHOST     \"$ip\""
    print -u$fd "set BSMIP          \"$ip\""
    print -u$fd "set BSMNAME        \"$srcid\""
    print -u$fd "set BSMUSER        \"$user\""
    print -u$fd "set BSMPSWD        \"\$env(\$MARKET.\$NEID\_passwd)\""
    print -u$fd "set BSMSRCDIR      \"$srcdir\""
    print -u$fd "set BSMID          \"$bsmid\""
    print -u$fd "set MTXNAME        \"$mtxid\""
    print -u$fd "set SECURERETRIEVE \"$secureretrieve\""
    print -u$fd "set SECUREDELIVER  \"$securedeliver\""
    print -u$fd "set PSWD_AUTH      \"$passwordauth\""    
    print -u$fd ""
    print -u$fd 'set LOCALDIR       "$env(FLEXDAHOME)/data/${MARKET}_${NETYPE}${NEID}/${DTYPE}"'
    print -u$fd "set NDAYS          \"$ndays\""
    print -u$fd ""
}


################################################################################
# Prints bsmcnfp icf                                                            
################################################################################
print_bsmcnfp_icf()
{
	typeset fd=${1:-1}
    typeset ip=${2:-ip}
    typeset srcid=${3:-id}    
    typeset bsmid=${4:-bsmid}
    typeset mtxid=${5:-mtxid}
    typeset user=${6:-user}
    typeset pswd=${7:-pswd}
    typeset cnfpdir=${8:-dir}
    typeset tmadj=${9:-0}
    typeset secureretrieve=${10:-1}    
    typeset securedeliver=${11:-1}
    typeset passwordauth=${12:-N}
    typeset ndays=${13:-2}
    
    print -u$fd "#"
    print -u$fd "# Application Variables:"
    print -u$fd "#"
    print -u$fd "#    ICFBEHIND      Number of minutes to delay an interval"
    print -u$fd "#    REMOTEHOST     Variable needed by icf_chat.exp same as BSMIP"
    print -u$fd "#    BSMIP          BSM IP address"
    print -u$fd "#    BSMNAME        BSM Name"
    print -u$fd "#    BSMUSER        Login account user for BSM"
    print -u$fd "#    BSMPSWD        Login account password for BSM. Use single quotes ' ' to"
    print -u$fd "#                   enclose password containing characters such as $; i.e 'Pa\$\$w0rd'"
    print -u$fd "#    CNFPDIR        Directory for the CNFP data"
    print -u$fd "#    MTXNAME        MTX Name"
    print -u$fd "#    BSMID          BSM Id"
    print -u$fd "#    SECURERETRIEVE Use normal ftp (0) or scp (1) when retrieving files"
    print -u$fd "#    SECUREDELIVER  Use normal ftp (0) or scp (1) when transferring files to Prospect server"    
    print -u$fd "#    PSWD_AUTH      Allow password-based authentication for ssh connection (Y/N)"
    print -u$fd "#                   Will be used only if SECURERETRIEVE/SECUREDELIVER is set to 1"    
    print -u$fd "#"
    print -u$fd "#    LOCALDIR       Local directory for the collected data"
    print -u$fd "#    NDAYS          Number of days to keep files in FlexDA server"
    print -u$fd ""
    print -u$fd "set ICFBEHIND      \"$tmadj\""
    print -u$fd "set REMOTEHOST     \"$ip\""
    print -u$fd "set BSMIP          \"$ip\""
    print -u$fd "set BSMNAME        \"$srcid\""
    print -u$fd "set BSMUSER        \"$user\""
    print -u$fd "set BSMPSWD        \"\$env(\$MARKET.\$NEID\_passwd)\""
    print -u$fd "set CNFPDIR        \"$cnfpdir\""
    print -u$fd "set MTXNAME        \"$mtxid\""
    print -u$fd "set BSMID          \"$bsmid\""
    print -u$fd "set SECURERETRIEVE \"$secureretrieve\""
    print -u$fd "set SECUREDELIVER  \"$securedeliver\""
    print -u$fd "set PSWD_AUTH      \"$passwordauth\""    
    print -u$fd ""
    print -u$fd 'set LOCALDIR       "$env(FLEXDAHOME)/data/${MARKET}_${NETYPE}${NEID}/${DTYPE}"'
    print -u$fd "set NDAYS          \"$ndays\""
    print -u$fd ""
}


################################################################################
# Prints bsmcsvs icf                                                            
################################################################################
print_bsmcsvs_icf()
{
	typeset fd=${1:-1}
    typeset ip=${2:-ip}
    typeset srcid=${3:-id}    
    typeset bsmid=${4:-bsmid}
    typeset mtxid=${5:-mtxid}
    typeset user=${6:-user}
    typeset pswd=${7:-pswd}
    typeset csvsdir=${8:-dir}
    typeset tmadj=${9:-0}
    typeset secureretrieve=${10:-1}    
    typeset securedeliver=${11:-1}
    typeset passwordauth=${12:-N}    
    typeset ndays=${13:-2}
    
    print -u$fd "#"
    print -u$fd "# Application Variables:"
    print -u$fd "#"
    print -u$fd "#    ICFBEHIND      Number of minutes to delay an interval"
    print -u$fd "#    REMOTEHOST     Variable needed by icf_chat.exp same as BSMIP"
    print -u$fd "#    BSMIP          BSM IP address"
    print -u$fd "#    BSMNAME        BSM Name"
    print -u$fd "#    BSMUSER        Login account user for BSM"
    print -u$fd "#    BSMPSWD        Login account password for BSM. Use single quotes ' ' to"
    print -u$fd "#                   enclose password containing characters such as $; i.e 'Pa\$\$w0rd'"    
    print -u$fd "#    CSVSDIR        Directory for the CSVS data"
    print -u$fd "#    MTXNAME        MTX Name"
    print -u$fd "#    BSMID          BSM Id"
    print -u$fd "#    SECURERETRIEVE Use normal ftp (0) or scp (1) when retrieving files"
    print -u$fd "#    SECUREDELIVER  Use normal ftp (0) or scp (1) when transferring files to Prospect server"    
    print -u$fd "#    PSWD_AUTH      Allow password-based authentication for ssh connection (Y/N)"
    print -u$fd "#                   Will be used only if SECURERETRIEVE/SECUREDELIVER is set to 1"    
    print -u$fd "#"
    print -u$fd "#    LOCALDIR       Local directory for the collected data"
    print -u$fd "#    NDAYS          Number of days to keep files in FlexDA server"
    print -u$fd ""
    print -u$fd "set ICFBEHIND      \"$tmadj\""
    print -u$fd "set REMOTEHOST     \"$ip\""
    print -u$fd "set BSMIP          \"$ip\""
    print -u$fd "set BSMNAME        \"$srcid\""
    print -u$fd "set BSMUSER        \"$user\""
    print -u$fd "set BSMPSWD        \"\$env(\$MARKET.\$NEID\_passwd)\""
    print -u$fd "set CSVSDIR        \"$csvsdir\""
    print -u$fd "set MTXNAME        \"$mtxid\""
    print -u$fd "set BSMID          \"$bsmid\""
    print -u$fd "set SECURERETRIEVE \"$secureretrieve\""
    print -u$fd "set SECUREDELIVER  \"$securedeliver\""
    print -u$fd "set PSWD_AUTH      \"$passwordauth\""    
    print -u$fd ""
    print -u$fd 'set LOCALDIR       "$env(FLEXDAHOME)/data/${MARKET}_${NETYPE}${NEID}/${DTYPE}"'
    print -u$fd "set NDAYS          \"$ndays\""
    print -u$fd ""
}



################################################################################
# Prints mtxom icf
################################################################################
print_mtxom_icf()
{
    typeset fd=${1:-1}
    typeset ip=${2:-ip}
    typeset user=${3:-user}
    typeset pswd=${4:-pswd}
    typeset srcid=${5:-id}
    typeset mtxid=${6:-mtxid}
    typeset tmadj=${7:-0}
    typeset securedeliver=${8:-1}
    typeset passwordauth=${9:-N}
    typeset ndays=${10:-2}

    print -u$fd "#"
    print -u$fd "# Application Variables:"
    print -u$fd "#"
    print -u$fd "#    ICFBEHIND       Number of minutes to delay an interval"
    print -u$fd "#    REMOTEHOST      Variable needed by icf_chat.exp same as MTXIP"
    print -u$fd "#    MTXIP           MTX IP address"
    print -u$fd "#    MTXNAME         MTX Name"
    print -u$fd "#    MTXUSER         Login account user for MTX"
    print -u$fd "#    MTXPSWD         Login account password for MTX. Use single quotes ' ' to"
    print -u$fd "#                    enclose password containing characters such as $; i.e 'Pa\$\$w0rd'"
    print -u$fd "#    SECUREDELIVER   Use normal ftp (0) or scp (1) when transferring files to Prospect server"    
    print -u$fd "#    PSWD_AUTH       Allow password-based authentication for ssh connection (Y/N)"
    print -u$fd "#                    Will be used only if SECUREDELIVER is set to 1"    
    print -u$fd "#"
    print -u$fd "#    LOCAL_MTXOMDEST Local MTXOM data destination directory"
    print -u$fd "#    LOCAL_MTXCFGDIR Local MTXCFG data directory"
    print -u$fd "#    NDAYS           Number of days to keep files in FlexDA server"
    print -u$fd ""
    print -u$fd "set ICFBEHIND      \"$tmadj\""
    print -u$fd "set REMOTEHOST     \"$ip\""
    print -u$fd "set MTXIP          \"$ip\""
    print -u$fd "set MTXNAME        \"$srcid\""
    print -u$fd "set MTXUSER        \"$user\""
    print -u$fd "set MTXPSWD        \"\$env(\$MARKET.\$NEID\_passwd)\""
    print -u$fd "set SECUREDELIVER  \"$securedeliver\""
    print -u$fd "set PSWD_AUTH      \"$passwordauth\""    
    print -u$fd ""
    print -u$fd 'set LOCAL_MTXOMDEST "$env(FLEXDAHOME)/data/${MARKET}_${NETYPE}${NEID}/${DTYPE}/dest"'
    print -u$fd 'set LOCAL_MTXCFGDIR "$env(FLEXDAHOME)/data/${MARKET}_${NETYPE}${NEID}/trkmem"'
    print -u$fd "set NDAYS          \"$ndays\""
    print -u$fd ""
}


################################################################################
# Prints pvgsta icf
################################################################################
print_pvgsta_icf()
{
    typeset fd=${1:-1}
    typeset ip=${2:-ip}
    typeset user=${3:-user}
    typeset pswd=${4:-pswd}
    typeset pgmscid=${5:-pgmscid}
    typeset srcid=${6:-pvgid}
    typeset nodeid=${7:-nodeid}
    typeset dsid=${8:-dsid}
    typeset srcdir=${9:-srcdir}
    typeset tmadj=${10:-0}
    typeset secureretrieve=${11:-1}
    typeset securedeliver=${12:-1}
    typeset passwordauth=${13:-N}    
    typeset ndays=${14:-2}

    print -u$fd "#"
    print -u$fd "# Application Variables:"
    print -u$fd "#"
    print -u$fd "#    ICFBEHIND      Number of minutes to delay an interval"
    print -u$fd "#    REMOTEHOST     Variable needed by icf_chat.exp same as MTXIP"
    print -u$fd "#    MDMID          MDM Source Id"
    print -u$fd "#    MDMIP          MDM IP address"
    print -u$fd "#    MDMUSER        Login account user for MDM"
    print -u$fd "#    MDMPSWD        Login account password for MDM. Use single quotes ' ' to"
    print -u$fd "#                   enclose password containing characters such as $; i.e 'Pa\$\$w0rd'"    
    print -u$fd "#    MDMBASEDIR     Source directory"
    print -u$fd "#"
    print -u$fd "#    PGMSCID        Source PGMSC Id"
    print -u$fd "#    PVGID          Source PVG Id"
    print -u$fd "#    NODEID         Source Node Id"
    print -u$fd "#    SECURERETRIEVE Use normal ftp (0) or scp (1) when retrieving files"
    print -u$fd "#    SECUREDELIVER  Use normal ftp (0) or scp (1) when transferring files to Prospect server"
    print -u$fd "#    PSWD_AUTH      Allow password-based authentication for ssh connection (Y/N)"
    print -u$fd "#                   Will be used only if SECURERETRIEVE/SECUREDELIVER is set to 1"
    print -u$fd "#"
    print -u$fd "#    LOCALDIR       Local RNCOM data directory"
    print -u$fd "#    NDAYS          Number of days to keep files in FlexDA server"
    print -u$fd ""
    print -u$fd "set ICFBEHIND      \"$tmadj\""
    print -u$fd "set REMOTEHOST     \"$ip\""
    print -u$fd "set MDMID          \"$dsid\""
    print -u$fd "set MDMIP          \"$ip\""
    print -u$fd "set MDMUSER        \"$user\""
    print -u$fd "set MDMPSWD        \"\$env(\$MARKET.\$NEID\_passwd)\""
    print -u$fd "set MDMBASEDIR     \"$srcdir\""
    print -u$fd ""
    print -u$fd "set PGMSCID        \"$pgmscid\""
    print -u$fd "set PVGID          \"$srcid\""
    print -u$fd "set NODEID         \"$nodeid\""
    print -u$fd "set SECURERETRIEVE \"$secureretrieve\""
    print -u$fd "set SECUREDELIVER  \"$securedeliver\""
    print -u$fd "set PSWD_AUTH      \"$passwordauth\""    
    print -u$fd ""
    print -u$fd 'set LOCALDIR       "$env(FLEXDAHOME)/data/${MARKET}_${NETYPE}${NEID}/${DTYPE}"'
    print -u$fd "set NDAYS          \"$ndays\""
    print -u$fd ""
}


################################################################################
# Prints rncom icf
################################################################################
print_rncom_icf()
{
    typeset fd=${1:-1}
    typeset ip=${2:-ip}
    typeset user=${3:-user}
    typeset pswd=${4:-pswd}
    typeset emsid=${5:-id}
    typeset srcid=${6:-id}
    typeset srcdir=${7:-srcdir}
    typeset flist=${8:-flist}
    typeset tmadj=${9:-0}
    typeset scratcharea=${10:-0}
    typeset secureretrieve=${11:-1}
    typeset securedeliver=${12:-1}
    typeset passwordauth=${13:-N}
    typeset rmtcmprs=${14:-N}
    typeset -i dombatchsize=${15:-0}
    typeset -u domcollection=${16:-N}
    typeset ndays=${17:-2}


    print -u$fd "#"
    print -u$fd "# Application Variables:"
    print -u$fd "#"
    print -u$fd "#    ICFBEHIND      Number of minutes to delay an interval"
    print -u$fd "#    REMOTEHOST     Variable needed by icf_chat.exp same as MTXIP"
    print -u$fd "#    EMSIP          EMS IP address"
    print -u$fd "#    EMSNAME        EMS Name"
    print -u$fd "#    RNCID          RNC Id"
    print -u$fd "#    EMSUSER        Login account user for EMS"
    print -u$fd "#    EMSPSWD        Login account password for EMS. Use single quotes ' ' to"
    print -u$fd "#                   enclose password containing characters such as $; i.e 'Pa\$\$w0rd'"
    print -u$fd "#    EMSBASEDIR     Source directory"
    print -u$fd "#    SCRATCHAREA    Temporary scratch area for RNC data processing"
    print -u$fd "#    SECURERETRIEVE Use normal ftp (0) or scp (1) when retrieving files"
    print -u$fd "#    SECUREDELIVER  Use normal ftp (0) or scp (1) when transferring files to Prospect server"
    print -u$fd "#    PSWD_AUTH      Allow password-based authentication for ssh connection (Y/N)"
    print -u$fd "#                   Will be used only if SECURERETRIEVE/SECUREDELIVER is set to 1"
    print -u$fd "#    REMOTE_COMPRESSION Compress source files at remote server before transfer to DA server"
    print -u$fd "#    DOM_BATCH_SIZE Number of DOMs to collect per batch."
	print -u$fd "#    DOM_COLLECTION To enable DOM file collection and processing."
    print -u$fd "#"
    print -u$fd "#    LOCALDIR       Local RNCOM data directory"
    print -u$fd "#    NDAYS          Number of days to keep files in FlexDA server"
    print -u$fd ""
    print -u$fd "set ICFBEHIND      \"$tmadj\""
    print -u$fd "set REMOTEHOST     \"$ip\""
    print -u$fd "set EMSIP          \"$ip\""
    print -u$fd "set EMSNAME        \"$emsid\""
    print -u$fd "set RNCID          \"$srcid\""
    print -u$fd "set EMSUSER        \"$user\""
    print -u$fd "set EMSPSWD        \"\$env(\$MARKET.\$NEID\_passwd)\""
    print -u$fd "set EMSFILELIST    \"$flist\""
    print -u$fd "set EMSBASEDIR     \"$srcdir\""
    print -u$fd ""
    print -u$fd 'set LOCALDIR       "$env(FLEXDAHOME)/data/${MARKET}_${NETYPE}${NEID}/${DTYPE}"'
    print -u$fd "set SCRATCHAREA    \"$scratcharea\""
    print -u$fd "set SECURERETRIEVE \"$secureretrieve\""
    print -u$fd "set SECUREDELIVER  \"$securedeliver\""
    print -u$fd "set PSWD_AUTH      \"$passwordauth\""
    print -u$fd "set REMOTE_COMPRESSION \"$rmtcmprs\""
    print -u$fd "set DOM_BATCH_SIZE \"$dombatchsize\""
	print -u$fd "set DOM_COLLECTION \"$domcollection\""
	print -u$fd "set NDAYS          \"$ndays\""
    print -u$fd ""
}


################################################################################
# Prints rnccfg icf
################################################################################
print_rnccfg_icf()
{
    typeset fd=${1:-1}
    typeset ip=${2:-ip}
    typeset user=${3:-user}
    typeset pswd=${4:-pswd}
    typeset emsid=${5:-id}
    typeset srcid=${6:-id}
    typeset srcdir=${7:-srcdir}
    typeset -l concat=${8:-concat}
    typeset tmadj=${9:-0}
    typeset secureretrieve=${10:-1}
    typeset securedeliver=${11:-1}
    typeset passwordauth=${12:-N}
    typeset emsrnclist=${13:-emsrnclist} 
    typeset cfgtarget=${14:-cfgtarget}
    typeset ndays=${15:-2}
    
    if [ $concat == "y" ] 
    then
        flist="${CONCATDOMCFGFILELIST}"
    else
        flist="${DOMCFGFILELIST}"
    fi

    print -u$fd "#"
    print -u$fd "# Application Variables:"
    print -u$fd "#"
    print -u$fd "#    ICFBEHIND      Number of minutes to delay an interval"
    print -u$fd "#    REMOTEHOST     Variable needed by icf_chat.exp same as MTXIP"
    print -u$fd "#    EMSIP          EMS IP address"
    print -u$fd "#    EMSNAME        EMS Name"
    print -u$fd "#    RNCID          RNC Id"
    print -u$fd "#    EMSUSER        Login account user for EMS"
    print -u$fd "#    EMSPSWD        Login account password for EMS. Use single quotes ' ' to"
    print -u$fd "#                   enclose password containing characters such as $; i.e 'Pa\$\$w0rd'"    
    print -u$fd "#    EMSBASEDIR     Source directory"
    print -u$fd "#    SECURERETRIEVE Use normal ftp (0) or scp (1) when retrieving files"
    print -u$fd "#    SECUREDELIVER  Use normal ftp (0) or scp (1) when transferring files to Prospect server"    
    print -u$fd "#    PSWD_AUTH      Allow password-based authentication for ssh connection (Y/N)"
    print -u$fd "#                   Will be used only if SECURERETRIEVE/SECUREDELIVER is set to 1"    
    print -u$fd "#"
    print -u$fd "#    LOCALDIR       Local RNCCFG data directory"
    if [ $concat == "y" ] 
    then
        print -u$fd "#    CFGTARGET      Target directory of candidateRncQuery file"
        print -u$fd "#    EMSRNCCFG      EMS and RNC list"
    fi
    print -u$fd "#    NDAYS          Number of days to keep files in FlexDA server"
    print -u$fd ""
    print -u$fd "set ICFSNAP        \"1\""
    print -u$fd "set ICFBEHIND      \"$tmadj\""
    print -u$fd "set REMOTEHOST     \"$ip\""
    print -u$fd "set EMSIP          \"$ip\""
    print -u$fd "set EMSNAME        \"$emsid\""
    print -u$fd "set EMSUSER        \"$user\""
    print -u$fd "set RNCID          \"$srcid\""
    print -u$fd "set EMSPSWD        \"\$env(\$MARKET.\$NEID\_passwd)\""
    print -u$fd "set EMSBASEDIR     \"$srcdir\""
    print -u$fd "set SECURERETRIEVE \"$secureretrieve\""
    print -u$fd "set SECUREDELIVER  \"$securedeliver\""
    print -u$fd "set PSWD_AUTH      \"$passwordauth\""    
    print -u$fd ""
    print -u$fd "set CFGFILELIST    \"$flist\""
    print -u$fd ""
    print -u$fd 'set LOCALDIR       "$env(FLEXDAHOME)/data/${MARKET}_${NETYPE}${NEID}/${DTYPE}"'
    if [ $concat == "y" ] 
    then
        print -u$fd "set CFGTARGET      \"$cfgtarget\""
        print -u$fd "set EMSRNCCFG      \"$emsrnclist\""
    fi
    print -u$fd "set NDAYS          \"$ndays\""
    print -u$fd ""
}

################################################################################
# Prints sdmom icf
################################################################################
print_sdmom_icf()
{
    typeset fd=${1:-1}
    typeset ip=${2:-ip}
    typeset user=${3:-user}
    typeset pswd=${4:-pswd}
    typeset srcid=${5:-id}
    typeset mscid=${6:-mscid}
    typeset srcdir=${7:-srcdir}
    typeset cbmsdir=${8:-cbmsdir}
    typeset srcopt=${9:-sdm}
    typeset colmult=${10:-no}
    typeset mvsrc=${11:-no}
    typeset sdmddir=${12:-sdmddir}
    typeset cbmddir=${13:-cbmddir}
    typeset tmadj=${14:-0}
    typeset secureretrieve=${15:-1}
    typeset securedeliver=${16:-1}
    typeset passwordauth=${17:-N}
    typeset ndays=${18:-2}
    typeset mtxname=${19:-mtxname}

    print -u$fd "#"
    print -u$fd "# Application Variables:"
    print -u$fd "#"
    print -u$fd "#    ICFBEHIND      Number of minutes to delay an interval"
    print -u$fd "#    REMOTEHOST     Variable needed by icf_chat.exp same as MTXIP"
    print -u$fd "#    SDMIP          SDM IP address"
    print -u$fd "#    SDMNAME        MSC Name"
    print -u$fd "#    MTXNAME        MTX Name"
    print -u$fd "#    SDMUSER        Login account user for SDM"
    print -u$fd "#    SDMPSWD        Login account password for SDM. Use single quotes ' ' to"
    print -u$fd "#                   enclose password containing characters such as $; i.e 'Pa\$\$w0rd'"    
    print -u$fd "#    SDMBASEDIR     Source directory"
    print -u$fd "#    CBMBASEDIR     CBM source directory"
    print -u$fd "#    SOURCEOPT      Option for DA to select the source : "
    print -u$fd "#                   'sdm' for SDM only, 'cbm' for CBM only, 'both' for SDM and CBM"
    print -u$fd "#    COLMULT        Option on whether to collect multiple files per interval (yes, no)"
    print -u$fd "#    MVSRC          Option on whether to move the original source files to other directory (yes, no)"
    print -u$fd "#    SDMDDIR        SDM 'closedSent' directory"
    print -u$fd "#    CBMDDIR        CBM 'closedSent' directory"
    print -u$fd "#    SECURERETRIEVE Use normal ftp (0) or scp (1) when retrieving files"
    print -u$fd "#    SECUREDELIVER  Use normal ftp (0) or scp (1) when transferring files to Prospect server"    
    print -u$fd "#    PSWD_AUTH      Allow password-based authentication for ssh connection (Y/N)"
    print -u$fd "#                   Will be used only if SECURERETRIEVE/SECUREDELIVER is set to 1"    
    print -u$fd "#"
    print -u$fd "#    LOCALDIR       Local SDMOM data directory"
    print -u$fd "#    NDAYS          Number of days to keep files in FlexDA server"
    print -u$fd ""
    print -u$fd "set ICFBEHIND      \"$tmadj\""
    print -u$fd "set REMOTEHOST     \"$ip\""
    print -u$fd "set SDMIP          \"$ip\""
    print -u$fd "set SDMID          \"$srcid\""
    print -u$fd "set MSCNAME        \"$mscid\""
    print -u$fd "set MTXNAME        \"$mtxname\""
    print -u$fd "set SDMUSER        \"$user\""
    print -u$fd "set SDMPSWD        \"\$env(\$MARKET.\$NEID\_sdmpasswd)\""
    print -u$fd "set SDMDATATYPE    \"$srcid\""
    print -u$fd "set SDMBASEDIR     \"$srcdir\""
    print -u$fd "set CBMBASEDIR     \"$cbmsdir\""
    print -u$fd "set SOURCEOPT      \"$srcopt\""
    print -u$fd "set COLMULT        \"$colmult\""
    print -u$fd "set MVSRC          \"$mvsrc\""
    print -u$fd "set SDMDDIR        \"$sdmddir\""
    print -u$fd "set CBMDDIR        \"$cbmddir\""
    print -u$fd "set SECURERETRIEVE \"$secureretrieve\""
    print -u$fd "set SECUREDELIVER  \"$securedeliver\""
    print -u$fd "set PSWD_AUTH      \"$passwordauth\""    
    print -u$fd ""
    print -u$fd 'set LOCALDIR       "$env(FLEXDAHOME)/data/${MARKET}_${NETYPE}${NEID}/${DTYPE}"'
    print -u$fd "set NDAYS          \"$ndays\""
    print -u$fd ""
}


################################################################################
# Prints mtx trkmem icf
################################################################################
print_trkmem_icf()
{
    typeset fd=${1:-1}
    typeset ip=${2:-ip}
    typeset user=${3:-user}
    typeset pswd=${4:-pswd}
    typeset srcid=${5:-id}
    typeset tmadj=${6:-0}
    typeset secureretrieve=${7:-1}
    typeset securedeliver=${8:-1}
    typeset passwordauth=${9:-N}
    typeset ndays=${10:-2}

    print -u$fd "#"
    print -u$fd "# Application Variables:"
    print -u$fd "#"
    print -u$fd "#    ICFBEHIND       Number of minutes to delay an interval"
    print -u$fd "#    REMOTEHOST      Variable needed by icf_chat.exp same as MTXIP"
    print -u$fd "#    MTXIP           MTX IP address"
    print -u$fd "#    MTXNAME         MTX Name"
    print -u$fd "#    MTXUSER         Login account user for MTX"
    print -u$fd "#    MTXPSWD         Login account password for MTX. Use single quotes ' ' to"
    print -u$fd "#                    enclose password containing characters such as $; i.e 'Pa\$\$w0rd'"
    print -u$fd "#    SECURERETRIEVE  Use normal ftp (0) or scp (1) when retrieving files"
    print -u$fd "#    SECUREDELIVER   Use normal ftp (0) or scp (1) when transferring files to Prospect server"    
    print -u$fd "#    PSWD_AUTH       Allow password-based authentication for ssh connection (Y/N)"
    print -u$fd "#                    Will be used only if SECURERETRIEVE/SECUREDELIVER is set to 1"    
    print -u$fd "#"
    print -u$fd "#    LOCAL_MTXCFGDIR Local MTXCFG data directory"
    print -u$fd "#    NDAYS           Number of days to keep files in FlexDA server"
    print -u$fd ""
    print -u$fd "set ICFBEHIND      \"$tmadj\""
    print -u$fd "set REMOTEHOST     \"$ip\""
    print -u$fd "set MTXIP          \"$ip\""
    print -u$fd "set MTXNAME        \"$srcid\""
    print -u$fd "set MTXUSER        \"$user\""
    print -u$fd "set MTXPSWD        \"\$env(\$MARKET.\$NEID\_passwd)\""
    print -u$fd "set SECURERETRIEVE \"$secureretrieve\""
    print -u$fd "set SECUREDELIVER  \"$securedeliver\""
    print -u$fd "set PSWD_AUTH      \"$passwordauth\""    
    print -u$fd ""
    print -u$fd 'set LOCAL_MTXCFGDIR "$env(FLEXDAHOME)/data/${MARKET}_${NETYPE}${NEID}/${DTYPE}"'
    print -u$fd "set NDAYS          \"$ndays\""
    print -u$fd ""
}


################################################################################
# Prints mtx tables icf
################################################################################
print_tables_icf()
{ 
    typeset fd=${1:-1}
    typeset ip=${2:-ip}
    typeset user=${3:-user}
    typeset pswd=${4:-pswd}
    typeset srcid=${5:-id}
    typeset mtxtbls=${6:-mtxtables}
    typeset tmadj=${7:-0}
    typeset cbmpassthrough=${8:-cbmpassthrough}
    typeset cbmip=${9:-cbmip}
    typeset cbmuser=${10:-cbmuser}
    typeset cbmpswd=${11:-cbmpswd}
    typeset secureretrieve=${12:-1}    
    typeset securedeliver=${13:-1}
    typeset passwordauth=${14:-N}    
    typeset ndays=${15:-2}
    set -A tbls $(echo ${mtxtbls} | tr "|" " ")

    print -u$fd "#"
    print -u$fd "# Application Variables:"
    print -u$fd "#"
    print -u$fd "#    ICFBEHIND       Number of minutes to delay an interval"
    print -u$fd "#    REMOTEHOST      Variable needed by icf_chat.exp same as MTXIP"
    print -u$fd "#    MTXIP           MTX IP address"
    print -u$fd "#    MTXNAME         MTX Name"
    print -u$fd "#    MTXUSER         Login account user for MTX"
    print -u$fd "#    MTXPSWD         Login account password for MTX. Use single quotes ' ' to"
    print -u$fd "#                    enclose password containing characters such as $; i.e 'Pa\$\$w0rd'"
    print -u$fd "#    SECURERETRIEVE  Use normal ftp (0) or scp (1) when retrieving files"
    print -u$fd "#    SECUREDELIVER   Use normal ftp (0) or scp (1) when transferring files to Prospect server"    
    print -u$fd "#    PSWD_AUTH       Allow password-based authentication for ssh connection (Y/N)"
    print -u$fd "#                    Will be used only if SECURERETRIEVE/SECUREDELIVER is set to 1"   
    print -u$fd "#    CBMPASSTHROUGH     Connect through CBM or direct to MTX (Y/N)" 
    if [ "$cbmpassthrough" == "Y" ]
    then
        print -u$fd "#    CBMIP           CBM IP address"
        print -u$fd "#    CBMUSER         Login account user for CBM"
        print -u$fd "#    CBMPSWD         Login account password for CBM. Use single quotes ' ' to"
        print -u$fd "#                    enclose password containing characters such as $; i.e 'Pa\$\$w0rd'"  
    fi 
    print -u$fd "#    MTXTABLES       MTX Tables"
    print -u$fd "#"
    print -u$fd "#    LOCAL_MTXCFGDIR Local MTXCFG data directory"
    print -u$fd "#    NDAYS           Number of days to keep files in FlexDA server"
    print -u$fd ""
    print -u$fd "set ICFBEHIND      \"$tmadj\""
    print -u$fd "set REMOTEHOST     \"$ip\""
    print -u$fd "set MTXIP          \"$ip\""
    print -u$fd "set MTXNAME        \"$srcid\""
    print -u$fd "set MTXUSER        \"$user\""
    print -u$fd "set MTXPSWD        \"\$env(\$MARKET.\$NEID\_passwd)\""
    print -u$fd "set MTXTABLES      \"${tbls[*]}\""
    print -u$fd "set SECURERETRIEVE \"$secureretrieve\""
    print -u$fd "set SECUREDELIVER  \"$securedeliver\""
    print -u$fd "set PSWD_AUTH      \"$passwordauth\""    
    print -u$fd ""
    print -u$fd "set CBMPASSTHROUGH    \"$cbmpassthrough\""
    if [ "$cbmpassthrough" == "Y" ]
    then
        print -u$fd "set CBMIP          \"$cbmip\""
        print -u$fd "set CBMUSER        \"$cbmuser\""
        print -u$fd "set CBMPSWD        \"\$env(\$MARKET.CBM.\$NEID\_passwd)\""
        print -u$fd ""
    fi
    print -u$fd 'set LOCAL_MTXCFGDIR "$env(FLEXDAHOME)/data/${MARKET}_${NETYPE}${NEID}/${DTYPE}"'
    print -u$fd "set NDAYS          \"$ndays\""
    print -u$fd ""
}

################################################################################
# Prints mtx tables icf
################################################################################
print_mtxtab_icf()
{
    typeset fd=${1:-1}
    typeset ip=${2:-ip}
    typeset user=${3:-user}
    typeset pswd=${4:-pswd}
    typeset srcid=${5:-id}
    typeset mtxid=${6:-mtxid}
    typeset srcdir=${7:-srcdir}
    typeset tmadj=${8:-0}
    typeset secureretrieve=${9:-1}    
    typeset securedeliver=${10:-1}
    typeset passwordauth=${11:-N}    
    typeset ndays=${12:-2}

    print -u$fd "#"
    print -u$fd "# Application Variables:"
    print -u$fd "#"
    print -u$fd "#    ICFBEHIND       Number of minutes to delay an interval"
    print -u$fd "#    REMOTEHOST      Variable needed by icf_chat.exp same as SDMIP"
    print -u$fd "#    SDMIP           SDM IP address"
    print -u$fd "#    SDMNAME         SDM Name"
    print -u$fd "#    MTXNAME         MTX Name"
    print -u$fd "#    SDMUSER         Login account user for SDM"
    print -u$fd "#    SDMPSWD         Login account password for SDM. Use single quotes ' ' to"
    print -u$fd "#                    enclose password containing characters such as $; i.e 'Pa\$\$w0rd'"
    print -u$fd "#    SECURERETRIEVE  Use normal ftp (0) or scp (1) when retrieving files"
    print -u$fd "#    SECUREDELIVER   Use normal ftp (0) or scp (1) when transferring files to Prospect server"    
    print -u$fd "#    PSWD_AUTH       Allow password-based authentication for ssh connection (Y/N)"
    print -u$fd "#                    Will be used only if SECURERETRIEVE/SECUREDELIVER is set to 1"    
    print -u$fd "#"
    print -u$fd "#    LOCAL_SDMCFGDIR Local SDMCFG data directory"
    print -u$fd "#    NDAYS           Number of days to keep files in FlexDA server"
    print -u$fd ""
    print -u$fd "set ICFBEHIND      \"$tmadj\""
    print -u$fd "set REMOTEHOST     \"$ip\""
    print -u$fd "set SDMIP          \"$ip\""
    print -u$fd "set SDMNAME        \"$srcid\""
    print -u$fd "set MTXNAME        \"$mtxid\""
    print -u$fd "set SRCDIR         \"$srcdir\""
    print -u$fd "set SDMUSER        \"$user\""
    print -u$fd "set SDMPSWD        \"\$env(\$MARKET.\$NEID\_sdmpasswd)\""
    print -u$fd "set SECURERETRIEVE \"$secureretrieve\""
    print -u$fd "set SECUREDELIVER  \"$securedeliver\""
    print -u$fd "set PSWD_AUTH      \"$passwordauth\""    
    print -u$fd ""
    print -u$fd 'set LOCAL_MTXCFGDIR "$env(FLEXDAHOME)/data/${MARKET}_${NETYPE}${NEID}/${DTYPE}"'
    print -u$fd "set NDAYS          \"$ndays\""
    print -u$fd ""
}


################################################################################
# Prints uspom icf
################################################################################
print_uspom_icf()
{
    typeset fd=${1:-1}
    typeset pip=${2:-ip}
    typeset puser=${3:-user}
    typeset ppswd=${4:-pswd}
    typeset psrcid=${5:-id}
    typeset psrcdir=${6:-srcdir}
    typeset bip=${7:-ip}
    typeset buser=${8:-user}
    typeset bpswd=${9:-pswd}
    typeset bsrcid=${10:-id}
    typeset bsrcdir=${11:-srcdir}
    typeset pgmscid=${12:-pgmscid}
    typeset uspid=${13:-uspid}
    typeset tmadj=${14:-0}
    typeset secureretrieve=${15:-1}    
    typeset securedeliver=${16:-1}
    typeset passwordauth=${17:-N}    
    typeset ndays=${18:-2}

    print -u$fd "# Application Variables:"
    print -u$fd "#"
    print -u$fd "#  ICFBEHIND          Number of minutes to delay an interval"
    print -u$fd "#  REMOTEHOST         Variable needed by icf_chat.exp same as MTXIP"
    print -u$fd "#  PRIMARY(USPIP)     PRIMARY USP IP address"
    print -u$fd "#  PRIMARY(USERNAME)  Login account user for PRIMARY USP"
    print -u$fd "#  PRIMARY(PASSWORD)  Login account password for primary server. Use single quotes ' ' to"
    print -u$fd "#                     enclose password containing characters such as $; i.e 'Pa\$\$w0rd'"    
    print -u$fd "#  PRIMARY(BASEDIR)   Source directory"
    print -u$fd "#"
    print -u$fd "#  BACKUP(USPIP)      Secondary USP IP address"
    print -u$fd "#  BACKUP(USERNAME)   Login account user for SECONDARY USP"
    print -u$fd "#  BACKUP(PASSWORD)   Login account password for primary server. Use single quotes ' ' to"
    print -u$fd "#                     enclose password containing characters such as $; i.e 'Pa\$\$w0rd'"    
    print -u$fd "#  BACKUP(BASEDIR)    Source directory"
    print -u$fd "#  SECURERETRIEVE     Use normal ftp (0) or scp (1) when retrieving files"
    print -u$fd "#  SECUREDELIVER      Use normal ftp (0) or scp (1) when transferring files to Prospect server"    
    print -u$fd "#  PSWD_AUTH          Allow password-based authentication for ssh connection (Y/N)"
    print -u$fd "#                     Will be used only if SECURERETRIEVE/SECUREDELIVER is set to 1"    
    print -u$fd "#"
    print -u$fd "#  LOCALDIR           Local USPOM data directory"
    print -u$fd "#  NDAYS              Number of days to keep files in FlexDA server"
    print -u$fd ""
    print -u$fd "set ICFBEHIND         \"$tmadj\""
    print -u$fd "set REMOTEHOST        \"$pip\""
    print -u$fd ""
    print -u$fd "set PRIMARY(USPID)    \"$psrcid\""
    print -u$fd "set PRIMARY(USPIP)    \"$pip\""
    print -u$fd "set PRIMARY(USERNAME) \"$puser\""
    print -u$fd "set PRIMARY(PASSWORD) {$ppswd}"
    print -u$fd "set PRIMARY(BASEDIR)  \"$psrcdir\""
    print -u$fd ""
    print -u$fd "set BACKUP(USPID)     \"$bsrcid\""
    print -u$fd "set BACKUP(USPIP)     \"$bip\""
    print -u$fd "set BACKUP(USERNAME)  \"$buser\""
    print -u$fd "set BACKUP(PASSWORD)  {$bpswd}"
    print -u$fd "set BACKUP(BASEDIR)   \"$bsrcdir\""
    print -u$fd ""
    print -u$fd "set USPID             \"$uspid\""
    print -u$fd "set PGMSCID           \"$pgmscid\""
    print -u$fd "set SECURERETRIEVE    \"$secureretrieve\""
    print -u$fd "set SECUREDELIVER     \"$securedeliver\""
    print -u$fd "set PSWD_AUTH         \"$passwordauth\""    
    print -u$fd ""
    print -u$fd 'set LOCALDIR          "$env(FLEXDAHOME)/data/${MARKET}_${NETYPE}${NEID}/${DTYPE}"'
    print -u$fd "set NDAYS             \"$ndays\""
    print -u$fd ""
}


################################################################################
# Print mtxlog icf
################################################################################
print_mtxlog_icf()
{
    typeset fd=${1:-1}
    typeset ip=${2:-ip}
    typeset user=${3:-user}
    typeset pswd=${4:-pswd}
    typeset srcid=${5:-id}
    typeset lclass=${6:-logclass}
    typeset tmadj=${7:-0}
    typeset secureretrieve=${8:-1}    
    typeset securedeliver=${9:-1}
    typeset passwordauth=${10:-N}    
    typeset ndays=${11:-2}

    print -u$fd "#"
    print -u$fd "# Application Variables:"
    print -u$fd "#"
    print -u$fd "#    ICFSNAP         Enable snapshot mode"
    print -u$fd "#    ICFBEHIND       Number of minutes to delay an interval"
    print -u$fd "#"
    print -u$fd "#    REMOTEHOST      Variable needed by icf_chat.exp same as MTXIP"
    print -u$fd "#    MTXIP           MTX IP address"
    print -u$fd "#    MTXNAME         MTX Name"
    print -u$fd "#    MTXUSER         Login account user for MTX"
    print -u$fd "#    MTXPSWD         Login account password for MTX. Use single quotes ' ' to"
    print -u$fd "#                    enclose password containing characters such as $; i.e 'Pa\$\$w0rd'"
    print -u$fd "#    SECURERETRIEVE  Use normal ftp (0) or scp (1) when retrieving files"
    print -u$fd "#    SECUREDELIVER   Use normal ftp (0) or scp (1) when transferring files to Prospect server"    
    print -u$fd "#    PSWD_AUTH       Allow password-based authentication for ssh connection (Y/N)"
    print -u$fd "#                    Will be used only if SECURERETRIEVE/SECUREDELIVER is set to 1"    
    print -u$fd "#"
    print -u$fd "#    LOCALDIR        Local data directory"
    print -u$fd "#    NDAYS           Number of days to keep files in FlexDA server"
    print -u$fd ""
    print -u$fd "set ICFSNAP        \"1\""
    print -u$fd "set ICFBEHIND      \"$tmadj\""

    print -u$fd "set REMOTEHOST     \"$ip\""
    print -u$fd "set MTXIP          \"$ip\""
    print -u$fd "set MTXNAME        \"$srcid\""
    print -u$fd "set MTXUSER        \"$user\""
    print -u$fd "set MTXPSWD        \"\$env(\$MARKET.\$NEID\_passwd)\""
    print -u$fd "set SECURERETRIEVE \"$secureretrieve\""
    print -u$fd "set SECUREDELIVER  \"$securedeliver\""
    print -u$fd "set PSWD_AUTH      \"$passwordauth\""    
    

    # Determine the log classes
    if [ $lclass == "actlog" ]
    then
	# Non-XA Core Logs (ACT100, ACT102)
        print -u$fd "set LOGCLASS(ACT100) \"open act 100; back; back;\""
        print -u$fd "set LOGCLASS(ACT102) \"open act 102;\""
        print -u$fd "set FILEEXT        \"ACT\""

    elif [ $lclass == "caplog" ]
    then
	# XA Core Logs (CAP100, CAP101, CAP103)
        print -u$fd "set LOGCLASS(CAP100) \"open cap 100;\""
        print -u$fd "set LOGCLASS(CAP101) \"open cap 101; back; back;\""
        #print -u$fd "set LOGCLASS(CAP102) \"open cap 102; back; back;\""
        print -u$fd "set LOGCLASS(CAP103) \"open cap 103; back; back;\""
        print -u$fd "set FILEEXT        \"CAP\""
    else
        print -u$fd "set MTXLOGCFG      \"\$env(FLEXDAHOME)/cfg/ntmtxlogs.cfg\""

    fi

    print -u$fd ""
    print -u$fd 'set LOCALDIR       "$env(FLEXDAHOME)/data/${MARKET}_${NETYPE}${NEID}/${DTYPE}"'
    print -u$fd "set NDAYS          \"$ndays\""
    print -u$fd ""

}


################################################################################
# Print ppcstaget icf
################################################################################
print_ppcstaget_icf()
{
    typeset fd=${1:-1}
    typeset ip=${2:-ip}
    typeset user=${3:-user}
    typeset pswd=${4:-pswd}
    typeset srcid=${5:-id}
    typeset nodeid=${6:-nodeid}
    typeset srcdir=${7:-stadir}
    typeset mdm=`echo ${8:-mdm} | tr [:upper:] [:lower:]`
    typeset tmadj=${9:-0}
    typeset secureretrieve=${10:-1}    
    typeset passwordauth=${11:-N}    
    typeset ndays=${12:-2}

    print -u$fd "#"
    print -u$fd "# Application Variables:"
    print -u$fd "#"
    print -u$fd "#    ICFBEHIND       Number of minutes to delay an interval"
    print -u$fd "#    REMOTEHOST      Variable needed by icf_chat.exp same as MTXIP"
    print -u$fd "#    MDMNAME         MDM Name"
    print -u$fd "#    PPCIP           PPC/MDP IP address"
    print -u$fd "#    PPCNAME         PPC Name"
    print -u$fd "#    PPCUSER         Login account user for PPC"
    print -u$fd "#    PPCPSWD         Login account password for PPC. Use single quotes ' ' to"
    print -u$fd "#                    enclose password containing characters such as $; i.e 'Pa\$\$w0rd'"    
    print -u$fd "#    PPCNODEID       MTX Tables"
    print -u$fd "#    PPCDIR          Source directory"
    print -u$fd "#    SECURERETRIEVE  Use normal ftp (0) or scp (1) when retrieving files"
    print -u$fd "#    PSWD_AUTH       Allow password-based authentication for ssh connection (Y/N)"
    print -u$fd "#                    Will be used only if SECURERETRIEVE is set to 1"    
    print -u$fd "#"
    print -u$fd "#    LOCALDIR        Local data directory"
    print -u$fd "#    NDAYS           Number of days to keep files in FlexDA server"
    print -u$fd ""
    print -u$fd "set ICFBEHIND      \"$tmadj\""
    print -u$fd "set REMOTEHOST     \"$ip\""
    print -u$fd "set MDMNAME        \"$mdm\""
    print -u$fd "set PPCIP          \"$ip\""
    print -u$fd "set PPCUSER        \"$user\""
    print -u$fd "set PPCPSWD        \"\$env(\$MARKET.\$MDMNAME\_passwd)\""
    print -u$fd "set PPCNAME        \"$srcid\""
    print -u$fd "set PPCNODEID      \"$nodeid\""
    print -u$fd "set PPCDIR         \"$srcdir\""
    print -u$fd "set SECURERETRIEVE \"$secureretrieve\""
    print -u$fd "set PSWD_AUTH      \"$passwordauth\""    
    print -u$fd ""
    print -u$fd 'set LOCALDIR       "$env(FLEXDAHOME)/data/${MARKET}_${NETYPE}${NEID}/${DTYPE}/src"'
    print -u$fd "set NDAYS          \"$ndays\""
    print -u$fd ""

}


################################################################################
# Print ppcstadist icf
################################################################################
print_ppcstadist_icf()
{
    typeset fd=${1:-1}
    typeset -l market=${2:-"goodmarket"}
    typeset -l netype=${3:-"netype"}
    typeset -l neid=${4:-"neid"}
    typeset -l dtype=${5:-"dtype"}
    typeset -l direct=${6:-"dist"}
    typeset securedeliver=${7:-1}
    typeset passwordauth=${8:-N}
    typeset ndays=${9:-2}

    print -u$fd "#"
    print -u$fd "# TITLE:   NT PPCSTA DATA TRANSFER"
    print -u$fd "#"
    print -u$fd "# SITE:    $FLEXDASITE"
    print -u$fd "#"
    print -u$fd "# HOST:    $HOST"
    print -u$fd "#"
    print -u$fd "#"
    print -u$fd "# ICF Variables:"
    print -u$fd "#"
    print -u$fd "#    ICFBIN        Location of ICF binaries."
    print -u$fd ""
    print -u$fd "set MARKET         \"$market\""
    print -u$fd "set NETYPE         \"$netype\""
    print -u$fd "set NEID           \"$neid\""
    print -u$fd "set DTYPE          \"$dtype\""
    print -u$fd "set DIRECT         \"$direct\""
    print -u$fd 'set TARGET         "$NETYPE$NEID.$DTYPE.$DIRECT"'
    print -u$fd ""
    print -u$fd 'set ICFBIN         "$env(FLEXDAHOME)/bin"'
    print -u$fd 'set ICFSCRIPT      "$env(FLEXDAHOME)/scripts"'
    print -u$fd ""
    print -u$fd "#"
    print -u$fd "# Application Variables:"
    print -u$fd "#"
    print -u$fd "#    SRCDIR          Source data directory"
    print -u$fd "#"
    print -u$fd "#    LOCALDIR        Local destination data directory"
    print -u$fd "#    NDAYS           Number of days to keep files in FlexDA server"
    print -u$fd "#    SECUREDELIVER   Use normal ftp (0) or scp (1) when transferring files to Prospect server"    
    print -u$fd "#    PSWD_AUTH       Allow password-based authentication for ssh connection (Y/N)"
    print -u$fd "#                    Will be used only if SECUREDELIVER is set to 1"    
    print -u$fd ""
    print -u$fd 'set SRCDIR         "$env(FLEXDAHOME)/data/${MARKET}_${NETYPE}${NEID}/${DTYPE}/dest"'
    print -u$fd ""
    print -u$fd 'set LOCALDIR       "$env(FLEXDAHOME)/data/${MARKET}_${NETYPE}${NEID}/${DTYPE}/dist"'
    print -u$fd "set NDAYS          \"$ndays\""
    print -u$fd "set SECUREDELIVER  \"$securedeliver\""
    print -u$fd "set PSWD_AUTH      \"$passwordauth\""    
    print -u$fd ""
}

################################################################################
# Print pdsnom icf
################################################################################
print_pdsnom_icf()
{
    typeset fd=${1:-1}
    typeset pdsnip=${2:-xxx.xxx.xx.xx}
    typeset pdsnuser=${3:-user}
    typeset pdsnpswd=${4:-password}
    typeset pdsnid=${5:-pdsnid}
    typeset pdsndir=${6:-dir}
    typeset dtype=${7:-dtype}
    typeset -i tmadj=${8:-0}
    typeset secureretrieve=${9:-1}    
    typeset securedeliver=${10:-1}
    typeset passwordauth=${11:-N}    
    typeset -i ndays=${12:-5}

    typeset PDSNOMS="PPP|CLOSED_RP"
    typeset PDSNFAOMS="PPP|CLOSED_RP|MIP_AA|MIP_FA|Device|ISP_ip|Stats_Service|Overload|Trunk|AAA"
    typeset PDSNHAOMS="MIP_HA|Device|ISP_ip|Stats_Service|Trunk|Overload|AAA"

    case $dtype in
    pdsnom )    typeset type=$PDSNOMS
            typeset dir=$pdsndir
            typeset pdsnnode=""
            ;;

    haom )  typeset type=$PDSNHAOMS
            typeset dir=$pdsndir
            typeset pdsnnode="HA"
            ;;

    faom )  typeset type=$PDSNFAOMS
            typeset dir=$pdsndir
            typeset pdsnnode="FA"
            ;;
    esac

    typeset pdsntype=`echo $type | tr "|" " "`

    print -u$fd "#"
    print -u$fd "# Application Variables:"
    print -u$fd "#"
    print -u$fd "#  ICFBEHIND       Number of minutes to delay an interval"
    print -u$fd "#  REMOTEHOST      Variable needed by icf_chat.exp same as PDSNIP"
    print -u$fd "#  PDSNID          PDSN Identification"
    print -u$fd "#  PDSNIP          Remote PDSN IP address"
    print -u$fd "#  PDSNUSER        Login account user for PDSN"
    print -u$fd "#  PDSNPSWD        Login account password for PDSN. Use single quotes ' ' to"
    print -u$fd "#                  enclose password containing characters such as $; i.e 'Pa\$\$w0rd'"    
    print -u$fd "#  PDSNOMDIR       PDSN OM data directory"
    print -u$fd "#  PDSNNODE        PDSN Node type"
    print -u$fd "#  PDSNOMTYPE      PDSN OM Types"
    print -u$fd "#  SECURERETRIEVE  Use normal ftp (0) or scp (1) when retrieving files"
    print -u$fd "#  SECUREDELIVER   Use normal ftp (0) or scp (1) when transferring files to Prospect server"    
    print -u$fd "#  PSWD_AUTH       Allow password-based authentication for ssh connection (Y/N)"
    print -u$fd "#                  Will be used only if SECURERETRIEVE/SECUREDELIVER is set to 1"    
    print -u$fd "#"
    print -u$fd "#  LOCALDIR        Local directory for the collected data"
    print -u$fd "#  NDAYS           Number of days to keep files in FlexDA server"
    print -u$fd "#"
    print -u$fd ""
    print -u$fd "set ICFBEHIND  \"$tmadj\""
    print -u$fd "set REMOTEHOST \"$pdsnip\""
    print -u$fd "set PDSNIP     \"$pdsnip\""
    print -u$fd "set PDSNID     \"$pdsnid\""
    print -u$fd "set PDSNUSER   \"$pdsnuser\""
    print -u$fd "set PDSNPSWD   \"\$env(\$MARKET.\$NEID\_passwd)\""
    print -u$fd "set PDSNOMDIR  \"$dir\""
    print -u$fd "set PDSNNODE   \"$pdsnnode\""
    print -u$fd "set PDSNOMTYPE \"$pdsntype\""
    print -u$fd "set SECURERETRIEVE \"$secureretrieve\""
    print -u$fd "set SECUREDELIVER  \"$securedeliver\""
    print -u$fd "set PSWD_AUTH      \"$passwordauth\""    
    print -u$fd ""
    print -u$fd 'set LOCALDIR   "$env(FLEXDAHOME)/data/${MARKET}_${NETYPE}${NEID}/${DTYPE}"'
    print -u$fd "set NDAYS      \"$ndays\""
    print -u$fd ""

}


################################################################################
# Prints uas icf
################################################################################
print_uas_icf()
{
    typeset fd=${1:-1}
    typeset sip=${2:-ip}
    typeset suser=${3:-user}
    typeset spswd=${4:-pswd}
    typeset srcdir=${5:-srcdir}
    typeset nodetype=${6:-UAS}
    typeset nodename=${7:-NODE1}
    typeset reportname=${8:-UAS}
    typeset timezone=${9:-PST}
    typeset tmadj=${10:-0}
    typeset secureretrieve=${11:-1}
    typeset securedeliver=${12:-1}
    typeset passwordauth=${13:-N}
    typeset ndays=${14:-2}

    print -u$fd "# Application Variables:"
    print -u$fd "#"
    print -u$fd "#  ICFBEHIND       Number of minutes to delay an interval"
    print -u$fd "#  REMOTEHOST      Address of the UAS element manager"
    print -u$fd "#  SRCUSER         UAS login account user"
    print -u$fd "#  SRCPSWD         Login account password for UAS. Use single quotes ' ' to"
    print -u$fd "#                  enclose password containing characters such as $; i.e 'Pa\$\$w0rd'"    
    print -u$fd "#  SRCDIR          Directory name of UAS data"
    print -u$fd "#  NODETYPE        NodeType in UAS file names"
    print -u$fd "#  NODENAME        NodeName in UAS file names"
    print -u$fd "#  REPORTNAME      ReportName in UAS file names"
    print -u$fd "#  TIMEZONE        TimeZone in UAS file names"
    print -u$fd "#  SECURERETRIEVE  Use normal ftp (0) or scp (1) when retrieving files"
    print -u$fd "#  SECUREDELIVER   Use normal ftp (0) or scp (1) when transferring files to Prospect server"    
    print -u$fd "#  PSWD_AUTH       Allow password-based authentication for ssh connection (Y/N)"
    print -u$fd "#                  Will be used only if SECURERETRIEVE/SECUREDELIVER is set to 1"    
    print -u$fd "#"
    print -u$fd "#  LOCALDIR        Local USPOM data directory"
    print -u$fd "#  NDAYS           Number of days to keep files in FlexDA server"
    print -u$fd ""
    print -u$fd "set ICFBEHIND         \"$tmadj\""
    print -u$fd "set REMOTEHOST        \"$sip\""
    print -u$fd "set SRCUSER           \"$suser\""
    print -u$fd "set SRCPSWD           {$spswd}"
    print -u$fd "set SRCDIR            \"$srcdir\""
    print -u$fd "set NODETYPE          \"$nodetype\""
    print -u$fd "set NODENAME          \"$nodename\""
    print -u$fd "set REPORTNAME        \"$reportname\""
    print -u$fd "set TIMEZONE          \"$timezone\""
    print -u$fd "set SECURERETRIEVE    \"$secureretrieve\""
    print -u$fd "set SECUREDELIVER     \"$securedeliver\""
    print -u$fd "set PSWD_AUTH         \"$passwordauth\""    
    print -u$fd ""
    print -u$fd 'set LOCALDIR          "$env(FLEXDAHOME)/data/${MARKET}_${NETYPE}${NEID}/${DTYPE}"'
    print -u$fd "set NDAYS             \"$ndays\""
    print -u$fd ""
}


################################################################################
# Prints mxpt icf
################################################################################
print_mxpt_icf()
{
    typeset fd=${1:-1}
    typeset sip=${2:-ip}
    typeset suser=${3:-user}
    typeset spswd=${4:-pswd}
    typeset srcdir=${5:-srcdir}
    typeset srcid=${6:-mtxid}
    typeset tmadj=${7:-0}
    typeset secureretrieve=${8:-1}
    typeset securedeliver=${9:-1}
    typeset passwordauth=${10:-N}
    typeset ndays=${11:-2}

    print -u$fd "# Application Variables:"
    print -u$fd "#"
    print -u$fd "#  ICFBEHIND          Number of minutes to delay an interval"
    print -u$fd "#  REMOTEHOST         Variable required by icf_chat.exp same as SRCIP"
    print -u$fd "#  SRCIP              Source IP Address (use \"localhost\" if files are pushed onto the DA server)"
    print -u$fd "#  SRCUSER            Login account user"
    print -u$fd "#  SRCPSWD            Login account password for MXPT server. Use single quotes ' ' to"
    print -u$fd "#                     enclose password containing characters such as $; i.e 'Pa\$\$w0rd'"    
    print -u$fd "#  SRCDIR             Directory name of MXPT OM data"
    print -u$fd "#  MTXNAME            MTX Name"
    print -u$fd "#  TRKMEMCFGFILE      TRKMEM file path"
    print -u$fd "#  SECURERETRIEVE     Use normal ftp (0) or scp (1) when retrieving files"
    print -u$fd "#  SECUREDELIVER      Use normal ftp (0) or scp (1) when transferring files to Prospect server"    
    print -u$fd "#  PSWD_AUTH          Allow password-based authentication for ssh connection (Y/N)"
    print -u$fd "#                     Will be used only if SECURERETRIEVE/SECUREDELIVER is set to 1"    
    print -u$fd "#"
    print -u$fd "#  LOCALDIR           Local MXPT OM data directory"
    print -u$fd "#  NDAYS              Number of days to keep files in FlexDA server"
    print -u$fd ""
    print -u$fd "set ICFBEHIND         \"$tmadj\""
    print -u$fd "set REMOTEHOST        \"$sip\""
    print -u$fd "set SRCIP             \"$sip\""
    print -u$fd "set SRCUSER           \"$suser\""
    print -u$fd "set SRCPSWD           {$spswd}"
    print -u$fd "set SRCDIR            \"$srcdir\""
    print -u$fd "set MTXNAME           \"$srcid\""
    print -u$fd "set TRKMEMCFGFILE     \"\$env(FLEXDAHOME)/cfg/TRKMEM.cfg\""
    print -u$fd "set SECURERETRIEVE    \"$secureretrieve\""
    print -u$fd "set SECUREDELIVER     \"$securedeliver\""
    print -u$fd "set PSWD_AUTH         \"$passwordauth\""    
    print -u$fd ""
    print -u$fd 'set LOCALDIR          "$env(FLEXDAHOME)/data/${MARKET}_${NETYPE}${NEID}/${DTYPE}"'
    print -u$fd "set NDAYS             \"$ndays\""
    print -u$fd ""
}


################################################################################
# Prints pdsn16000 om icf
################################################################################
print_pdsn16000om_icf()
{
    typeset fd=${1:-1}
    typeset sip=${2:-ip}
    typeset suser=${3:-user}
    typeset spswd=${4:-pswd}
    typeset srcdir=${5:-srcdir}
    typeset pdsnid=${6:-pdsnid}
    typeset tmadj=${7:-0}
    typeset secureretrieve=${8:-1}
    typeset securedeliver=${9:-1}
    typeset passwordauth=${10:-N}
    typeset ndays=${11:-2}

    print -u$fd "# Application Variables:"
    print -u$fd "#"
    print -u$fd "#  ICFBEHIND          Number of minutes to delay an interval"
    print -u$fd "#  REMOTEHOST         Variable required by icf_chat.exp same as SRCIP"
    print -u$fd "#  SRCIP              Source IP Address (use \"localhost\" if files are pushed onto the DA server)"
    print -u$fd "#  SRCUSER            Login account user"
    print -u$fd "#  SRCPSWD            Login account password. Use single quotes ' ' to"
    print -u$fd "#                     enclose password containing characters such as $; i.e 'Pa\$\$w0rd'"    
    print -u$fd "#  SRCDIR             Directory name of PDSN16000 OM data"
    print -u$fd "#  PDSNID             PDSN Id"
    print -u$fd "#  SRCFILENAME        Source filename format"
    print -u$fd "#  CFGFILENAME        Bulkstat configuration filename"
    print -u$fd "#  SECURERETRIEVE     Use normal ftp (0) or scp (1) when retrieving files"
    print -u$fd "#  SECUREDELIVER      Use normal ftp (0) or scp (1) when transferring files to Prospect server"    
    print -u$fd "#  PSWD_AUTH          Allow password-based authentication for ssh connection (Y/N)"
    print -u$fd "#                     Will be used only if SECURERETRIEVE/SECUREDELIVER is set to 1"    
    print -u$fd "#"
    print -u$fd "#  LOCALDIR           Local data directory"
    print -u$fd "#  NDAYS              Number of days to keep files in FlexDA server"
    print -u$fd ""
    print -u$fd "set ICFBEHIND         \"$tmadj\""
    print -u$fd "set REMOTEHOST        \"$sip\""
    print -u$fd "set SRCIP             \"$sip\""
    print -u$fd "set SRCUSER           \"$suser\""
    print -u$fd "set SRCPSWD           \"$spswd\""
    print -u$fd "set SRCDIR            \"$srcdir\""
    print -u$fd "set PDSNID            \"$pdsnid\""
    print -u$fd "set CFGFILENAME       \"PDSN_ID.cfg\""
    print -u$fd "set SECURERETRIEVE    \"$secureretrieve\""
    print -u$fd "set SECUREDELIVER     \"$securedeliver\""
    print -u$fd "set PSWD_AUTH         \"$passwordauth\""    
    print -u$fd ""
    print -u$fd "# Default source filename format"
    print -u$fd "# set SRCFILENAME       \"\%Y\%m\%d_\%H\%M\%S_*.stat\""
    print -u$fd "# set SRCFILENAME       \"bulkstat\%Y\%m\%d\%H\%M??.txt\""
    print -u$fd ""
    print -u$fd 'set LOCALDIR          "$env(FLEXDAHOME)/data/${MARKET}_${NETYPE}${NEID}/${DTYPE}"'
    print -u$fd "set NDAYS             \"$ndays\""
    print -u$fd ""
}

################################################################################
# Prints ntmsta icf 
################################################################################
print_ntmsta_icf()
{
    typeset fd=${1:-1}
    typeset ip=${2:-ip}
    typeset user=${3:-user}
    typeset pswd=${4:-pswd}
    typeset srcid=${5:-id}
    typeset mscid=${6:-mscid}
    typeset srcdir=${7:-srcdir}
    typeset mvsrc=${8:-no}
    typeset ddir=${9:-ddir}
    typeset tmadj=${10:-0}
    typeset secureretrieve=${11:-1}
    typeset securedeliver=${12:-1}
    typeset passwordauth=${13:-N}
    typeset ndays=${14:-2}

    print -u$fd "#"
    print -u$fd "# Application Variables:"
    print -u$fd "#"
    print -u$fd "#  ICFBEHIND          Number of minutes to delay an interval"
    print -u$fd "#  REMOTEHOST         Variable required by icf_chat.exp same as SRCIP"
    print -u$fd "#  SRCIP              Source IP Address"
    print -u$fd "#  SRCID              MSC Name"
    print -u$fd "#  MTXNAME            MTX Name"
    print -u$fd "#  SRCUSER            Login account user"
    print -u$fd "#  SRCPSWD            Login account password. Use single quotes ' ' to"
    print -u$fd "#                     enclose password containing characters such as $; i.e 'Pa\$\$w0rd'"    
    print -u$fd "#  SRCDIR             Directory name of NTM STA/SN07 data"
    print -u$fd "#  MVSRC              Option on whether to move the original source files to other directory (yes,no)"
    print -u$fd "#  DDIR               'closedSent' directory"
    print -u$fd "#  SECURERETRIEVE     Use normal ftp (0) or scp (1) when retrieving files"
    print -u$fd "#  SECUREDELIVER      Use normal ftp (0) or scp (1) when transferring files to Prospect server"    
    print -u$fd "#  PSWD_AUTH          Allow password-based authentication for ssh connection (Y/N)"
    print -u$fd "#                     Will be used only if SECURERETRIEVE/SECUREDELIVER is set to 1"    
    print -u$fd "#"
    print -u$fd "#  LOCALDIR           Local data directory"
    print -u$fd "#  NDAYS              Number of days to keep files in FlexDA server"
    print -u$fd ""
    print -u$fd "set ICFBEHIND         \"$tmadj\""
    print -u$fd "set REMOTEHOST        \"$ip\""
    print -u$fd "set SRCIP             \"$ip\""
    print -u$fd "set SRCID             \"$srcid\""
    print -u$fd "set MTXNAME           \"$mscid\""
    print -u$fd "set SRCUSER           \"$user\""
    print -u$fd "set SRCPSWD           \"\$env(\$MARKET.\$NEID\_passwd)\""
    print -u$fd "set DATATYPE          \"$srcid\""
    print -u$fd "set SRCDIR            \"$srcdir\""
    print -u$fd "set MVSRC             \"$mvsrc\""
    print -u$fd "set DDIR              \"$ddir\""    
    print -u$fd "set SECURERETRIEVE    \"$secureretrieve\""
    print -u$fd "set SECUREDELIVER     \"$securedeliver\""
    print -u$fd "set PSWD_AUTH         \"$passwordauth\""    
    print -u$fd ""
    print -u$fd 'set LOCALDIR          "$env(FLEXDAHOME)/data/${MARKET}_${NETYPE}${NEID}/${DTYPE}"'
    print -u$fd "set NDAYS             \"$ndays\""
    print -u$fd ""
}

################################################################################
# Prints ntmmdm icf
################################################################################
print_ntmmdm_icf()
{
    typeset fd=${1:-1}
    typeset ip=${2:-ip}
    typeset user=${3:-user}
    typeset pswd=${4:-pswd}
    typeset srcid=${5:-id}
    typeset srcdir=${6:-srcdir}
    typeset mvsrc=${7:-no}
    typeset ddir=${8:-ddir}
    typeset tmadj=${9:-0}
    typeset secureretrieve=${10:-1}
    typeset securedeliver=${11:-1}
    typeset passwordauth=${12:-N}
    typeset ndays=${13:-2}
    typeset pvglist=${14:-pvglist}

    print -u$fd "#"
    print -u$fd "# Application Variables:"
    print -u$fd "#"
    print -u$fd "#  ICFBEHIND       Number of minutes to delay an interval"
    print -u$fd "#  REMOTEHOST      Variable needed by icf_chat.exp same as"
    print -u$fd "#                  MTXIP"
    print -u$fd "#  SRCIP           Source IP address"
    print -u$fd "#  SRCID           MSC Name"
    print -u$fd "#  MTXNAME         MTX Name"
    print -u$fd "#  SRCUSER         Login account user for SDM/BM"
    print -u$fd "#  SRCPSWD         Login account password for SDM/CBM. Use single quotes ' ' to"
    print -u$fd "#                  enclose password containing characters such as $; i.e 'Pa\$\$w0rd'"    
    print -u$fd "#  SRCDIR          Source directory"
    print -u$fd "#  MVSRC           Option on whether to move the original"
    print -u$fd "#                  source files to other directory (yes, no)"
    print -u$fd "#  DDIR           'closedSent' directory"
    print -u$fd "#  SECURERETRIEVE  Use normal ftp (0) or scp (1) when retrieving files"
    print -u$fd "#  SECUREDELIVER   Use normal ftp (0) or scp (1) when transferring files to Prospect server"    
    print -u$fd "#  PSWD_AUTH       Allow password-based authentication for ssh connection (Y/N)"
    print -u$fd "#                  Will be used only if SECURERETRIEVE/SECUREDELIVER is set to 1"    
    print -u$fd "#"
    print -u$fd "#  LOCALDIR        Local data directory"
    print -u$fd "#  PVG_LIST        The file which contains a list of MSC and related PVG"
    print -u$fd "#                  This list is used to lookup the list of PVG which related to the same MSC"
    print -u$fd "#                  Files will be collected from source directory base on the list."
    print -u$fd "#  NDAYS           Number of days to keep files in FlexDA"
    print -u$fd "#                  server"
    print -u$fd ""
    print -u$fd "set ICFBEHIND      \"$tmadj\""
    print -u$fd "set REMOTEHOST     \"$ip\""
    print -u$fd "set SRCIP          \"$ip\""
    print -u$fd "set SRCID          \"$srcid\""
    print -u$fd "set MTXNAME        \"$srcid\""
    print -u$fd "set SRCUSER        \"$user\""
    print -u$fd "set SRCPSWD        \"\$env(\$MARKET.\$NEID\_mdmpasswd)\""
    print -u$fd "set DATATYPE       \"$srcid\""
    print -u$fd "set SRCDIR         \"$srcdir\""
    print -u$fd "set MVSRC          \"$mvsrc\""
    print -u$fd "set DDIR           \"$ddir\""
    print -u$fd "set SECURERETRIEVE \"$secureretrieve\""
    print -u$fd "set SECUREDELIVER  \"$securedeliver\""
    print -u$fd "set PSWD_AUTH      \"$passwordauth\""    
    print -u$fd ""
    print -u$fd 'set LOCALDIR       "$env(FLEXDAHOME)/data/${MARKET}_${NETYPE}${NEID}/${DTYPE}"'
    print -u$fd "set PVG_LIST       \"$pvglist\""
    print -u$fd "set NDAYS          \"$ndays\""
    print -u$fd ""
}
################################################################################
# Prints chgpswd icf
################################################################################
print_chgpswd_icf()
{

    typeset fd=${1:-1}
    typeset market=${2:-mkt}

    print -u$fd "#"
    print -u$fd "# TITLE: Password Rotation"
    print -u$fd "#"
    print -u$fd "# SITE:  $FLEXDASITE"
    print -u$fd "#"
    print -u$fd "# HOST:  $HOST"
    print -u$fd "#"
    print -u$fd "#"
    print -u$fd "# ICF_CHAT Variables:"
    print -u$fd "#"
    print -u$fd "#    ICFBIN        Location of ICF binaries."
    print -u$fd "#    ICFSCRIPT     Location of ICF scripts."
    print -u$fd "#    ICFTABLE      Filename of ICF checkpoint table."
    print -u$fd "#    ICFAPP        Filename of ICF application."
    print -u$fd "#"
    print -u$fd ""
    print -u$fd "set MARKET         \"$market\""
    print -u$fd ""
    print -u$fd 'set ICFBIN         "$env(FLEXDAHOME)/bin"'
    print -u$fd 'set ICFSCRIPT      "$env(FLEXDAHOME)/scripts"'
    print -u$fd 'set ICFTABLE       "$env(FLEXDAHOME)/log/$MARKET.chgpswd.chk"'
    print -u$fd 'set ICFAPP         "$ICFSCRIPT/chgpswd.exp"'
    print -u$fd "set ICFCHGPSWDAPP  \"\$ICFBIN/pswdgen\""
    print -u$fd ""
    print -u$fd "#"
    print -u$fd "# Application Variables:"
    print -u$fd "#"
    print -u$fd "#    ICFCHGPSWDAPP Random password generator"
    print -u$fd "#    ICFPSWDCFG    Env variable pointing to Password file"
    print -u$fd "#    ICFSNAP       Enable snapshot mode"
    print -u$fd "#"
    print -u$fd "#    REMOTEHOST    Variable needed by icf_chat.exp same as MTXIP"
    print -u$fd "#    SWIP_LIST     Remote switch login information"
    print -u$fd ""
    print -u$fd "set ICFPSWDCFG     \"\$env(FLEXDAPSWDFILE)\""
    print -u$fd ""
    print -u$fd "set ICFSNAP        \"1\""
    print -u$fd "set REMOTEHOST     \"localhost\"" 
    print -u$fd "set SWIP_LIST      {"
    i=0
    mdm_list=""
    while ((i < ${#d_market[*]}))
    do
	typeset -l mkt=${d_market[$i]}
	typeset -l id=${d_srcid[$i]}
	typeset cbmpassthrough=${d_cbmpassthrough[$i]}
	typeset cbmuser=${d_cbmuser[$i]}
	typeset cbmpswd=${d_cbmpswd[$i]}
	typeset cbmip=${d_cbmip[$i]}
	typeset user=${d_srcuser[$i]}
	typeset pswd=${d_srcpswd[$i]}
	typeset ip=${d_srcip[$i]}
	typeset -l type=${d_type[$i]}
	typeset aip=${d_ashell[$i]}
	typeset bip=${d_bshell[$i]}
	typeset -u chgpswd=${d_chgpswd[$i]}

	if ([ "$mkt" == "$market" ] && [ "$chgpswd" == "Y" ])
	then
	  if [ "$type" == "ppc" ]
	  then
	      set -A mdm_list "$mdm_list ${d_datasrvid[$i]}|${user}|${ip}|$type"
	  else
	      if ([ "$type" == "mtx" ])
	      then
	         if ([ "$cbmpassthrough" == "Y" ])
	         then
	             print -u$fd "                   \"$cbmpassthrough,$mkt.CBM.$id,$mkt.$id $type $cbmuser,$user $cbmip,$ip $aip $bip\""
	         else
	             print -u$fd "                   \"$cbmpassthrough,$mkt.$id $type $user $ip $aip $bip\""
	         fi
	      else
	         print -u$fd "                   \"$mkt.$id $type $user $ip $aip $bip\""
	      fi
      fi
	fi
    ((i=i+1))
    done

    # Print ppc element separately to avoid duplicates since the MDM is the
    # data server and may holds several ppc nodes
    for val in `echo ${mdm_list[*]} |tr " " "\n"|sort -u`
    do
      	set -A mdm $(echo $val | tr "|" " ")
	typeset -l id=${mdm[0]}
	user=${mdm[1]}
	ip=${mdm[2]}
	type=${mdm[3]}
	print -u$fd "                   \"$market.$id $type $user $ip\""
    done

    print -u$fd "                   }"
    print -u$fd ""
}


################################################################################
# Creates da_pswd_lkup cfg
################################################################################
print_pswdlkup_cfg()
{
typeset fd=${1:-1}
typeset i=0
typeset ppclist=""

set -A arr_pswd $PASWD_NOT_MATCH

while ((i < ${#d_market[*]}))
do
    if [[ ${d_ntopts[$i]} == "mxptom" ]]
    then
        ((i=i+1))
        continue
    fi
    typeset -l mkt=${d_market[$i]}
    typeset -l id=${d_srcid[$i]}
    typeset -l d_svid=${d_datasrvid[$i]}
    typeset user=${d_srcuser[$i]}
    typeset pswd=${d_srcpswd[$i]}
    typeset cbmpswd=${d_cbmpswd[$i]}
    typeset cbmpassthrough=${d_cbmpassthrough[$i]}
    if [ ${d_type[$i]} == "ppc" ]
    then
	    set -A ppclist "$ppclist ${mkt}.${d_svid}|${pswd}"
    elif [ ${d_ntopts[$i]} == "sdmom" ] || [ ${d_ntopts[$i]} == "mtxtab" ]
    then
        print -u$fd "set env(${mkt}.${id}_sdmpasswd) {$pswd}"
    elif [ ${d_ntopts[$i]} == "ntmmdm" ]
    then
        print -u$fd "set env(${mkt}.${id}_mdmpasswd) {$pswd}"
    elif [ ${d_type[$i]} == "mtx" ] && [[ ${d_ntopts[$i]} == *tables* ]]
    then
        print -u$fd "set env(${mkt}.${id}_passwd)     {$pswd}"
        if [ "$cbmpassthrough" == "Y" ]
        then
            print -u$fd "set env(${mkt}.CBM.${id}_passwd) {$cbmpswd}"
        fi
    else
      typeset pswdflag=0
      
      for val in ${arr_pswd[@]} 
      do
        if [[ "${val%%;*}" == "${mkt}.${id}" ]]
        then
          pswdflag=1
	        print -u$fd "set env(${mkt}.${id}_passwd) ${val#*;}"
          break
        fi
      done
      
      if [ pswdflag -eq 0 ] 
      then
	      print -u$fd "set env(${mkt}.${id}_passwd) {$pswd}"
	    fi
	    
    fi
    ((i=i+1))
done

# Print MDM entries here
for mdm in `echo ${ppclist[*]} |tr " " "\n" |sort -u`
do
    set -A mdm_entry `echo ${mdm} | tr "|" " "`
    id=${mdm_entry[0]}
    pswd=${mdm_entry[1]}
	print -u$fd "set env(${id}_passwd)            {$pswd}"
done
}


################################################################################
# Creates nortel monitor config file
################################################################################
print_nortel_mon()
{
typeset    fd=${1:-1}
typeset -l optname=${2:-option_name}
typeset -u sysname=${3:-hostname}
typeset    m_detail

for opt in ${optname[*]}
do
    typeset -u grpname="$grpname nt${opt}"
done

typeset i=0
typeset n=0
while (($n < ${#d_market[*]}))
do
    found=0
    for opt in ${optname[*]}
    do
        echo ${d_ntopts[$n]} | tr "," " " | grep ${opt} >/dev/null
        if [ $? -eq 0 ]
        then
            typeset -u m_optname[$i]="nt${opt}"
            found=1
            break
        fi
    done

    if [[ $found -eq 0 ]]
    then
        ((n=n+1))
        continue
    fi

    typeset -u m_mktid[$i]=${d_market[$n]}
    typeset m_ip[$i]=${d_srcip[$n]}
    typeset -u m_id[$i]=${d_srcid[$n]}
    typeset -i m_nogrps[$i]=${d_nogrps[$n]}
    typeset m_port[$i]=${d_port[$n]}
    typeset m_dtypes[$i]=${d_ntopts[$n]}
    typeset m_omgrpscfg[$i]=${d_moncfg[$n]}
    typeset m_type[$i]=${d_type[$n]}
    typeset m_datasrvid[$i]=${d_datasrvid[$n]};
    typeset -u m_mtxid[$i]=${d_mtxid[$n]}
    typeset -u m_bsmid[$i]=${d_bsmid[$n]}
    typeset m_nodeid[$i]=${d_nodeid[$n]}
    typeset m_rdfcfg[$i]=${d_rdfcfg[$n]}
    typeset m_bdfdel[$i]=${d_bdfdel[$n]}
    typeset m_cbrscfg[$i]=${d_cbrscfg[$n]}
    typeset eval ${m_optname[$i]}[$i]=${m_id[$i]}

    #
    # Verify if the config file exists
    #
    if ([ ! -r $FLEXDAHOME/${m_omgrpscfg[$i]} ] && \
        [ ${m_optname[$i]} == "NTMTXOM" ])
    then
        read answer?"${cmd}: File ${m_omgrpscfg[$i]} not found, use default? [y|n]"
        case $answer in
            y|yes|YES ) typeset m_omgrpscfg[$i]="cfg/omgroups.cdma"
                        ;;

            * )         echo "${cmd}: Please make necessary changes in the\
				      configuration file and run setup again"
			exit 1
			;;
        esac
    fi

    if ([ ! -r $FLEXDAHOME/${m_rdfcfg[$i]} ] || \
        [ ! -r $FLEXDAHOME/${m_cbrscfg[$i]} ] && \
        [ ${m_optname[$i]} == "NTPPCSTA" ])
    then
        echo "${cmd}: The file ${m_rdfcfg[$i]} or ${m_cbrscfg[$i]} not found"
        echo "${cmd}: Please make necessary changes in the configuration file"
        echo "${cmd}: and run setup again"
        exit 1
    fi

    ((i=i+1))
    ((n=n+1))
done

print -u$fd "!"
print -u$fd "! NORTEL DA MONITOR SCRIPT"
print -u$fd "!"
print -u$fd ""
print -u$fd "system.name:			${sysname}"
print -u$fd ""
print -u$fd "${sysname}.groups:			${grpname[*]}"

for opt in ${grpname[*]}
do
    case $opt in
        NTMTXOM )   mon_proc="READER PARSER"
                    typeset grpid=${NTMTXOM[*]}
                    ;;

        NTPPCSTA )  mon_proc="PARSER"
                    typeset grpid=${NTPPCSTA[*]}
                    ;;
    esac

    print -u$fd "${sysname}.${opt}.groups:		${grpid}"
    for id in ${grpid}
    do
        print -u$fd "*${opt}.${id}.processes:	${mon_proc[*]}"
    done
    print -u$fd ""
done

print -u$fd ""
print -u$fd "!"
print -u$fd "! Global Defaults"
print -u$fd "!"
print -u$fd ""
print -u$fd "*wait:             10"
print -u$fd "*retry:            5"
print -u$fd "*timeout:          30"
print -u$fd "*delay:            10"
print -u$fd "*normal:           false"
print -u$fd ""
print -u$fd "!"
print -u$fd "! Start the threads in reverse order so that later stages will be ready and"
print -u$fd "! waiting for earlier stages."
print -u$fd "!"
print -u$fd ""
print -u$fd "*READER.start:    		2"
print -u$fd "*PARSER.start:    		1"
print -u$fd ""
print -u$fd "*READER.down:    		2"
print -u$fd "*PARSER.down:    		1"
print -u$fd ""
print -u$fd "!"
print -u$fd "! Allow infinite retries for all readers."
print -u$fd "!"
print -u$fd ""
print -u$fd "*READER.retry:    		-1"
print -u$fd ""

typeset d=0
while (($d < ${#m_id[*]}))
do
    typeset -l d_type="${m_type[$d]}"
    typeset    d_optname="${m_optname[$d]}"

    if [ $d_optname == "NTMTXOM" ]
    then
        typeset -l b_dir="${m_mktid[$d]}_${d_type}${m_id[$d]}"
        typeset    datatype="om"
        print -u$fd "!"
        print -u$fd "! $d_optname ${m_id[$d]}"
        print -u$fd "!"
        print -u$fd ""
        print -u$fd "*${d_optname}.${m_id[$d]}.READER.program: nt_aft_reader"
        print -u$fd "*${d_optname}.${m_id[$d]}.READER.argv: \\"
        print -u$fd "    -n ${m_mktid[$d]}_${m_id[$d]} -w 1800 \\"
        print -u$fd "    -L log/$b_dir/$datatype/get,aft.,.log,1440,800000,40 \\"
        print -u$fd "    ${m_port[$d]}@${m_ip[$d]} \\"
        print -u$fd "    data/$b_dir/$datatype/src"
        print -u$fd ""
        print -u$fd "*${d_optname}.${m_id[$d]}.PARSER.program: nt_mtxom_parse"
        print -u$fd "*${d_optname}.${m_id[$d]}.PARSER.argv: \\"
        print -u$fd "    -n ${m_mktid[$d]}_${m_id[$d]} \\"
        print -u$fd "    -b 2048 \\"
        print -u$fd "    -L log/$b_dir/$datatype/fmt,parse.,.log,1440,800000,40 \\"
        print -u$fd "    -m data/$b_dir/$datatype/arch \\"
        print -u$fd "    -C ${m_omgrpscfg[$d]}:${m_nogrps[$d]} \\"
        print -u$fd "    ${m_id[$d]} \\"
        print -u$fd "    data/$b_dir/$datatype/src \\"
        print -u$fd "    data/$b_dir/$datatype/dest \\"
        print -u$fd "    data/$b_dir/$datatype/fail"
        print -u$fd ""
    elif [ $d_optname == "NTPPCSTA" ]
    then
        typeset -l b_dir="${m_mktid[$d]}_${d_type}${m_id[$d]}"
        typeset    datatype="sta"
        print -u$fd "!"
        print -u$fd "! ${d_optname} ${m_id[$d]}"
        print -u$fd "!"
        print -u$fd ""
        print -u$fd "*${d_optname}.${m_id[$d]}.PARSER.program: nt_ppcsta_parse"
        print -u$fd "*${d_optname}.${m_id[$d]}.PARSER.argv: \\"
        print -u$fd "    -n ${m_mktid[$d]}_${m_id[$d]} \\"
        print -u$fd "    -b 2048 \\"
        print -u$fd "    -L log/$b_dir/$datatype/fmt,parse.,.log,1440,800000,40 \\"
        print -u$fd "    -m data/$b_dir/$datatype/arch \\"
        print -u$fd "    -C ${m_rdfcfg[$d]}:${m_bdfdel[$d]}:${m_cbrscfg[$d]} \\"
        print -u$fd "    ${m_mtxid[$d]}.${m_bsmid[$d]}.${m_id[$d]}.${m_nodeid[$d]} \\"
        print -u$fd "    data/$b_dir/$datatype/src \\"
        print -u$fd "    data/$b_dir/$datatype/dest \\"
        print -u$fd "    data/$b_dir/$datatype/fail"
        print -u$fd ""
    fi

    ((d=d+1))
done

}


################################################################################
# Create sendomshow icf
################################################################################
print_omshow_icf()
{
    typeset fd=${1:-1}
    typeset ldir=${2:-localdir}
    typeset omdir=${3:-omshowdir}
    typeset mtxid=${4:-}
    typeset ndays=${5:-2}
    #typeset omtype=${6:-"OMMTX CAUCPSCT ICPCP"}
    typeset omtype=${6:-"CAUCPSCT CAUSCT3V CAUSCT3D"}

    print -u$fd "#"
    print -u$fd "# TITLE:   NT OMSHOW DATA TRANSFER"
    print -u$fd "#"
    print -u$fd "# SITE:    $FLEXDASITE"
    print -u$fd "#"
    print -u$fd "# HOST:    $HOST"
    print -u$fd "#"
    print -u$fd "#"
    print -u$fd "# ICF Variables:"
    print -u$fd "#"
    print -u$fd "#    ICFBIN        Location of ICF binaries."
    print -u$fd ""
    print -u$fd 'set ICFBIN         "$env(FLEXDAHOME)/bin"'
    print -u$fd ""
    print -u$fd "#"
    print -u$fd "# Application Variables:"
    print -u$fd "#"
    print -u$fd "#    REMOTEHOST    Variable needed by icf_chat.exp same as MTXIP"
    print -u$fd "#    MTXID         MTX ID"
    print -u$fd "#    OMTYPE        OM Types"
    print -u$fd "#    OMSHOWDIR     Source OMSHOW data directory"
    print -u$fd "#    FILETIME      File modification time before transferring the OMSHOW files"
    print -u$fd "#"
    print -u$fd "#    LOCALDIR      Local destination data directory"
    print -u$fd "#    NDAYS         Number of days to keep files in FlexDA server"
    print -u$fd "#"
    print -u$fd "#    SECUREDELIVER   Use normal ftp (0) or scp (1) when transferring files to Prospect server"    
    print -u$fd "#    PSWD_AUTH       Allow password-based authentication for ssh connection (Y/N)"
    print -u$fd "#                    Will be used only if SECUREDELIVER is set to 1"    
    print -u$fd ""
    print -u$fd "set REMOTEHOST     \"127.0.0.1\""
    print -u$fd "set MTXID          \"$mtxid\""
    print -u$fd "set OMTYPE         \"$omtype\""
    print -u$fd ""
    print -u$fd "# Following are the placeholders that are used for the filename format"
    print -u$fd "#"
    print -u$fd "# %T - Timestamp in YYYYMMDDhhmmss"
    print -u$fd "# %M - MTX Id appearing on the file"
    print -u$fd "# %O - OM Group Name"
    print -u$fd "#"
    print -u$fd "# NEID(\$MTXID)     MTXID name in the file"
    print -u$fd "# FILEFMT(\$MTXID)  Filename's format (default in P_%T%M%O)"

    for mid in $mtxid
    do
        print -u$fd "set NEID($mid)     \"$mid\""
        print -u$fd "set FILEFMT($mid)  \"P_%T%M%O\""
        print -u$fd ""
    done

    print -u$fd "set OMSHOWDIR      \"$omdir\""
    print -u$fd "set FILETIME       \"2\""
    print -u$fd ""
    print -u$fd "set LOCALDIR       \"$ldir\""
    print -u$fd "set NDAYS          \"$ndays\""
    print -u$fd ""
    print -u$fd "set SECUREDELIVER  \"1\""
    print -u$fd "set PSWD_AUTH      \"N\""
    print -u$fd ""
    
}


################################################################################
# Compare cfg password against the $FLEXDAPSWDFILE
################################################################################
compare_pswd_cfg()
{
    typeset type=${1}
    typeset -l mkt=${2}
    typeset -l id=${3}
    typeset user=${4}
    typeset pswd=${5}
    typeset ret=0
    unset PSWDFILE

    if ([ -s "${FLEXDAPSWDFILE}" ] && [ -r "${FLEXDAPSWDFILE}" ])
    then
	    p=`grep "env(${mkt}.${id}_passwd)" ${FLEXDAPSWDFILE} | \
         head -1 | awk '{print $3}'`

	    if ([ "{$pswd}" != "$p" ] && [ -n "$p" ])
	    then
	      export PSWDFILE="$p"
	      ret=1
	    fi
    fi
    
    return $ret
}

is_firsttime()
{
    firsttime=1
    emsname1="$1"
    emslist={}

    i=1
    IFS=" "
    for ems in $2
    do
        emslist[$i]=$ems
        ((i=i+1))
    done

    for ems in ${emslist[@]}
    do
        # emsname already exist
        if [ "$emsname1" == "$ems" ]; then
            firsttime=0
        fi
    done

	echo $firsttime
}

################################################################################
# Validates configuration file and populate array
################################################################################
check_cfg_file()
{
    typeset cfg=${1}
    typeset tmpcfg=/tmp/da.cfg.$$
    typeset tmplog=/tmp/da.err.$$
    typeset diffpswd=""

    if [ ! -f $cfg ]
    then
	echo "${cmd}: Configuration file $cfg not found"
	exit 1
    fi

    # Remove invalid data in the configuration file
    cat $cfg | sed 's/\\ *$/\\/' | sed 's/ *= */=/g' | sed 's/ *, */,/g' | \
	sed '/^$/d' > $tmpcfg

    # Source configuration file and check for error
    . $tmpcfg 2>&1 2 >$tmplog


    if [ -s $tmplog ]
    then
	echo "${cmd}: Error reading configuration file: $cfg"
	exit 1;
    fi

    # Remove temporary files
    rm -f $tmpcfg $tmplog

    # Ensure that the correct number of attributes (na) have been specified
    # for lhost thost nortel
    typeset na_lhost=2
    typeset na_thost=4
    typeset na_ntcdma=1

    if ( [ `expr ${#lhost[*]} % $na_lhost` != 0 ] || \
	 [ `expr ${#thost[*]} % $na_thost` != 0 ] || \
	 [ `expr ${#ntcdma[*]} % $na_ntcdma` != 0 ] )
    then
	echo "${cmd}: Incorrect number of arguments for lhost, thost or ntcdma"
	echo "${cmd}: check the arguments for lhost or thost in $1"
	exit 1
    fi
    
    typeset j=0
    typeset i=0
    while (($j < ${#ntcdma_type[*]}))
    do

	# Get detailed information for each ntcdma type
	set -A detail $(eval echo \${ntcdma_${ntcdma_type[$j]}[*]})
	case ${ntcdma_type[$j]} in
	    bsm ) na_detail=22;;
	    mtx ) na_detail=19;;
	    mtxtab ) na_detail=13;;
	    ppc ) na_detail=21;;
	    rnc ) na_detail=20;;
	    pdsn) na_detail=13;;
	    usp)  na_detail=19;;
	    pvg)  na_detail=15;;
	    sdm)  na_detail=20;;
	    ntmmdm) na_detail=15;;
	    uas)  na_detail=16;;
	    mxpt) na_detail=13;;
      mg)   na_detail=15;;
	    pdsn16000) na_detail=13;;        
	    *)    echo "${cmd}: Invalid option name $c_optname"; exit 1;;
	esac

	if ([ ${#detail[*]} == 0 ] || \
	    [ `expr ${#detail[*]} % $na_detail` != 0 ])
	then
	    echo "${cmd}: ntcdma_${ntcdma_type[$j]} not specified properly"
	    ((j=j+1))
	    continue
	fi

	# Get ntcdma type detailed info
	typeset k=0
	while (($k < ${#detail[*]}))
	do
	    unset d_market[$i] d_tdir[$i] d_srcip[$i] d_srcid[$i]
	    unset d_datasrvid[$i] d_bsmid[$i] d_mtxid[$i] d_srcuser[$i]
	    unset d_srcpswd[$i] d_srcdir[$i] d_cfgdir[$i] d_chgpswd[$i]
	    unset d_ashell[$i] d_bshell[$i] d_ntopts[$i] d_tmadj[$i]
	    unset d_type[$i] d_nogrps[$i] d_port[$i] d_moncfg[$i]
	    unset d_omfnames[$i] d_cbrsname[$i] d_nodeid[$i]
	    unset d_rdfcfg[$i] d_bdfdel[$i] d_cbrscfg[$i]
	    unset d_bip[$i] d_buser[$i] d_bpswd[$i] d_bsdir[$i]
	    unset d_nodetype[$i] d_nodename[$i] d_rptname[$i] d_timezone[$i]
	    unset d_period[$i] d_rnccfgid[$i]
	    unset d_cbmsdir[$i] d_srcopt[$i] d_colmult[$i] d_mvsrc[$i] d_sdmddir[$i] d_cbmddir[$i]
	    unset d_ddir[$i]  d_scratcharea[$i] d_secureretrieve[$i] d_securedeliver[$i] d_pswd_auth[$i]
	    unset d_csvsdir[$i] d_cnfpdir[$i] d_rmt_cmprs[$i] d_dombatchsize[$i] d_domcollection[$i]
	    unset d_cbmpassthrough[$i] d_cbmip[$i] d_cbmuser[$i] d_cbmpswd[$i]
		unset d_allemslist[$i] d_concaton[$i] d_cfgtarget[$i]
	    unset d_pvglist[$i]

	    
	    case ${ntcdma_type[$j]} in
	    bsm )
		d_market[$i]=${detail[$k]};         ((k=k+1))
		d_tdir[$i]=${detail[$k]};           ((k=k+1))
		d_srcip[$i]=${detail[$k]};          ((k=k+1))
		d_srcid[$i]=${detail[$k]};          ((k=k+1))
		d_bsmid[$i]=${detail[$k]};          ((k=k+1))
		d_mtxid[$i]=${detail[$k]};          ((k=k+1))
		d_srcuser[$i]=${detail[$k]};        ((k=k+1))
		d_srcpswd[$i]=${detail[$k]};        ((k=k+1))
		d_srcdir[$i]=${detail[$k]};         ((k=k+1))
		d_bscdir[$i]=${detail[$k]};         ((k=k+1))
		d_cfgdir[$i]=${detail[$k]};         ((k=k+1))
		d_omfnames[$i]=${detail[$k]};       ((k=k+1))
		d_chgpswd[$i]=${detail[$k]};        ((k=k+1))
		d_ashell[$i]=${detail[$k]};         ((k=k+1))
		d_bshell[$i]=${detail[$k]};         ((k=k+1))
		d_ntopts[$i]=${detail[$k]};         ((k=k+1))
		d_tmadj[$i]=${detail[$k]};          ((k=k+1))
		d_csvsdir[$i]=${detail[$k]};        ((k=k+1)) 
		d_cnfpdir[$i]=${detail[$k]};        ((k=k+1))
        d_secureretrieve[$i]=${detail[$k]}; ((k=k+1))		
		d_securedeliver[$i]=${detail[$k]};  ((k=k+1))
		d_pswd_auth[$i]=${detail[$k]};      ((k=k+1))
		d_type[$i]=${ntcdma_type[$j]}
		;;
		
	    mtx )
		d_market[$i]=${detail[$k]};         ((k=k+1))
		d_tdir[$i]=${detail[$k]};           ((k=k+1))
		d_srcip[$i]=${detail[$k]};          ((k=k+1))
		d_srcid[$i]=${detail[$k]};          ((k=k+1))
		d_srcuser[$i]=${detail[$k]};        ((k=k+1))
		d_srcpswd[$i]=${detail[$k]};        ((k=k+1))
		d_nogrps[$i]=${detail[$k]};         ((k=k+1))
		d_port[$i]=${detail[$k]};           ((k=k+1))
		d_chgpswd[$i]=${detail[$k]};        ((k=k+1))
		d_ntopts[$i]=${detail[$k]};         ((k=k+1))
		d_moncfg[$i]=${detail[$k]};         ((k=k+1))
		d_tmadj[$i]=${detail[$k]};          ((k=k+1))
		d_cbmpassthrough[$i]=${detail[$k]};    ((k=k+1)) #cbmpassthrough
		d_cbmip[$i]=${detail[$k]};          ((k=k+1)) #CBM ip
		d_cbmuser[$i]=${detail[$k]};        ((k=k+1)) #CBM username
		d_cbmpswd[$i]=${detail[$k]};        ((k=k+1)) #CBM password
    d_secureretrieve[$i]=${detail[$k]}; ((k=k+1))		
		d_securedeliver[$i]=${detail[$k]};  ((k=k+1))
		d_pswd_auth[$i]=${detail[$k]};      ((k=k+1))
		d_type[$i]=${ntcdma_type[$j]}
		;;

	    mtxtab )
		d_market[$i]=${detail[$k]};         ((k=k+1))
		d_tdir[$i]=${detail[$k]};           ((k=k+1))
		d_srcip[$i]=${detail[$k]};          ((k=k+1))
		d_srcid[$i]=${detail[$k]};          ((k=k+1))
		d_mtxid[$i]=${detail[$k]};          ((k=k+1))
		d_srcdir[$i]=${detail[$k]};         ((k=k+1))
		d_srcuser[$i]=${detail[$k]};        ((k=k+1))
		d_srcpswd[$i]=${detail[$k]};        ((k=k+1))
		d_ntopts[$i]=${detail[$k]};         ((k=k+1))
		d_tmadj[$i]=${detail[$k]};          ((k=k+1))
        d_secureretrieve[$i]=${detail[$k]}; ((k=k+1))		
		d_securedeliver[$i]=${detail[$k]};  ((k=k+1))
		d_pswd_auth[$i]=${detail[$k]};      ((k=k+1))
		d_type[$i]=${ntcdma_type[$j]}
		;;

	    pdsn )
		d_market[$i]=${detail[$k]};   ((k=k+1))
		d_tdir[$i]=${detail[$k]};     ((k=k+1))
		d_srcip[$i]=${detail[$k]};    ((k=k+1))
		d_srcid[$i]=${detail[$k]};    ((k=k+1))
		d_srcuser[$i]=${detail[$k]};  ((k=k+1))
		d_srcpswd[$i]=${detail[$k]};  ((k=k+1))
		d_srcdir[$i]=${detail[$k]};   ((k=k+1))
		d_port[$i]=${detail[$k]};     ((k=k+1))
		d_ntopts[$i]=${detail[$k]};   ((k=k+1))
		d_tmadj[$i]=${detail[$k]};    ((k=k+1))
        d_secureretrieve[$i]=${detail[$k]}; ((k=k+1))		
		d_securedeliver[$i]=${detail[$k]};  ((k=k+1))
		d_pswd_auth[$i]=${detail[$k]};      ((k=k+1))
		d_chgpswd[$i]="N";
		d_type[$i]=${ntcdma_type[$j]}
		;;

	    ppc )
		d_market[$i]=${detail[$k]};         ((k=k+1))
		d_tdir[$i]=${detail[$k]};           ((k=k+1))
		d_srcip[$i]=${detail[$k]};          ((k=k+1))
		d_datasrvid[$i]=${detail[$k]};      ((k=k+1))
		d_bsmid[$i]=${detail[$k]};          ((k=k+1))
		d_mtxid[$i]=${detail[$k]};          ((k=k+1))
		d_srcid[$i]=${detail[$k]};          ((k=k+1))
		d_nodeid[$i]=${detail[$k]};         ((k=k+1))
		d_srcuser[$i]=${detail[$k]};        ((k=k+1))
		d_srcpswd[$i]=${detail[$k]};        ((k=k+1))
		d_srcdir[$i]=${detail[$k]};         ((k=k+1))
		d_rdfcfg[$i]=${detail[$k]};         ((k=k+1))
		d_bdfdel[$i]=${detail[$k]};         ((k=k+1))
		d_cbrscfg[$i]=${detail[$k]};        ((k=k+1))
		d_ntopts[$i]=${detail[$k]};         ((k=k+1))
		d_tmadj[$i]=${detail[$k]};          ((k=k+1))
		d_period[$i]=${detail[$k]};         ((k=k+1))
		d_chgpswd[$i]=${detail[$k]};        ((k=k+1))
        d_secureretrieve[$i]=${detail[$k]}; ((k=k+1))		
		d_securedeliver[$i]=${detail[$k]};  ((k=k+1))
		d_pswd_auth[$i]=${detail[$k]};      ((k=k+1))
		d_type[$i]=${ntcdma_type[$j]}
		;;

	    rnc )
		d_market[$i]=${detail[$k]};         ((k=k+1))
		d_tdir[$i]=${detail[$k]};           ((k=k+1))
		d_srcip[$i]=${detail[$k]};          ((k=k+1))
		d_datasrvid[$i]=${detail[$k]};      ((k=k+1))
		d_srcid[$i]=${detail[$k]};          ((k=k+1))
		d_srcuser[$i]=${detail[$k]};        ((k=k+1))
		d_srcpswd[$i]=${detail[$k]};        ((k=k+1))
		d_srcdir[$i]=${detail[$k]};         ((k=k+1))
		d_ntopts[$i]=${detail[$k]};         ((k=k+1))
		d_tmadj[$i]=${detail[$k]};          ((k=k+1))
		d_dombatchsize[$i]=${detail[$k]};   ((k=k+1))
		d_domcollection[$i]=${detail[$k]};  ((k=k+1))
		d_secureretrieve[$i]=${detail[$k]}; ((k=k+1))
		d_securedeliver[$i]=${detail[$k]};  ((k=k+1))
		d_pswd_auth[$i]=${detail[$k]};      ((k=k+1))
        d_rmt_cmprs[$i]=${detail[$k]};      ((k=k+1))
        d_scratcharea[$i]=${detail[$k]};    ((k=k+1))
		d_allemslist[$i]=${detail[$k]};    ((k=k+1))
		d_concaton[$i]=${detail[$k]};    ((k=k+1))
		d_cfgtarget[$i]=${detail[$k]};    ((k=k+1))
		d_chgpswd[$i]="N"
		d_type[$i]=${ntcdma_type[$j]}

		if [ "${d_ntopts[$i]}" == "rnccfg" ]
		then
       	    d_rnccfgid[$i]=${d_srcid[$i]}
		    d_srcid[$i]=${d_datasrvid[$i]}
		fi

        if [ "${d_ntopts[$i]}" == "rncom" ] && 
           [ "${d_rmt_cmprs[$i]}" == "Y" ] &&
           ([ "${d_dombatchsize[$i]}" == "0" ] || [ "${d_dombatchsize[$i]}" == "none" ])
        then
	        echo "${cmd}: Error: Option DOM_BATCH_SIZE should have value when option REMOTE_COMPRESSION set to 'Y': ${d_dombatchsize[$i]}"
	        exit 1
        fi

        if [ "${d_concaton[$i]}" == "Y" ] && [ "${d_ntopts[$i]}" == "rncom" ]
        then
            emsname="${d_datasrvid[$i]}"
            inlist=`echo ${omemslist[@]}`
            firsttime=`is_firsttime "$emsname" "$inlist"`

            if [ $firsttime -eq 1 ]; then
                inlist=`echo ${omemslistoff[@]}`
                firsttime=`is_firsttime "$emsname" "$inlist"`
                if [ $firsttime -eq 0 ]; then
                    echo "${cmd}: Warning: Only 1 entry of rncom per EMS ($emsname) is required when CONCAT_ON is set to \"Y\""
                fi
                omemslist[$i]=$emsname
            else
                echo "${cmd}: Warning: Only 1 entry of rncom per EMS ($emsname) is required when CONCAT_ON is set to \"Y\""
            fi
        elif [ "${d_concaton[$i]}" == "N" ] && [ "${d_ntopts[$i]}" == "rncom" ]
        then
            emsname="${d_datasrvid[$i]}"
            inlist=`echo ${omemslist[@]}`
            firsttime=`is_firsttime "$emsname" "$inlist"`

            if [ $firsttime -eq 0 ]; then
                echo "${cmd}: Warning: Only 1 entry of rncom per EMS ($emsname) is required when CONCAT_ON is set to \"Y\""
            else
                omemslistoff[$i]=$emsname
            fi
        elif [ "${d_concaton[$i]}" == "Y" ] && [ "${d_ntopts[$i]}" == "rnccfg" ]
        then
            emsname="${d_datasrvid[$i]}"
            inlist=`echo ${cfgemslist[@]}`
            firsttime=`is_firsttime "$emsname" "$inlist"`

            if [ $firsttime -eq 1 ]; then
                inlist=`echo ${cfgemslistoff[@]}`
                firsttime=`is_firsttime "$emsname" "$inlist"`
                if [ $firsttime -eq 0 ]; then
                    echo "${cmd}: Warning: Only 1 entry of rncom per EMS ($emsname) is required when CONCAT_ON is set to \"Y\""
                fi
                cfgemslist[$i]=$emsname
            else
                echo "${cmd}: Warning: Only 1 entry of rnccfg per EMS ($emsname) is required when CONCAT_ON is set to \"Y\""
            fi
        elif [ "${d_concaton[$i]}" == "N" ] && [ "${d_ntopts[$i]}" == "rnccfg" ]
        then
            emsname="${d_datasrvid[$i]}"
            inlist=`echo ${cfgemslist[@]}`
            firsttime=`is_firsttime "$emsname" "$inlist"`

            if [ $firsttime -eq 0 ]; then
                echo "${cmd}: Warning: Only 1 entry of rnccfg per EMS ($emsname) is required when CONCAT_ON is set to \"Y\""
            else
                cfgemslistoff[$i]=$emsname
            fi
        fi
		;;

	    usp )
		d_market[$i]=${detail[$k]};         ((k=k+1))
		d_tdir[$i]=${detail[$k]};           ((k=k+1))
		d_srcip[$i]=${detail[$k]};          ((k=k+1))
		d_srcid[$i]=${detail[$k]};          ((k=k+1))
		d_srcuser[$i]=${detail[$k]};        ((k=k+1))
		d_srcpswd[$i]=${detail[$k]};        ((k=k+1))
		d_srcdir[$i]=${detail[$k]};         ((k=k+1))
		d_bip[$i]=${detail[$k]};            ((k=k+1))
		d_bid[$i]=${detail[$k]};            ((k=k+1))
		d_buser[$i]=${detail[$k]};          ((k=k+1))
		d_bpswd[$i]=${detail[$k]};          ((k=k+1))
		d_bsdir[$i]=${detail[$k]};          ((k=k+1))
		d_nodeid[$i]=${detail[$k]};         ((k=k+1))
		d_mscid[$i]=${detail[$k]};          ((k=k+1))
		d_ntopts[$i]=${detail[$k]};         ((k=k+1))
		d_tmadj[$i]=${detail[$k]};          ((k=k+1))
		d_secureretrieve[$i]=${detail[$k]}; ((k=k+1))		
		d_securedeliver[$i]=${detail[$k]};  ((k=k+1))
		d_pswd_auth[$i]=${detail[$k]};      ((k=k+1))		
		d_chgpswd[$i]="N"
		d_type[$i]=${ntcdma_type[$j]}
		;;

	    pvg )
		d_market[$i]=${detail[$k]};         ((k=k+1))
		d_tdir[$i]=${detail[$k]};           ((k=k+1))
		d_srcip[$i]=${detail[$k]};          ((k=k+1))
		d_srcid[$i]=${detail[$k]};          ((k=k+1))
		d_mscid[$i]=${detail[$k]};          ((k=k+1))
		d_datasrvid[$i]=${detail[$k]};      ((k=k+1))
		d_nodeid[$i]=${detail[$k]};         ((k=k+1))
		d_srcuser[$i]=${detail[$k]};        ((k=k+1))
		d_srcpswd[$i]=${detail[$k]};        ((k=k+1))
		d_srcdir[$i]=${detail[$k]};         ((k=k+1))
		d_ntopts[$i]=${detail[$k]};         ((k=k+1))
		d_tmadj[$i]=${detail[$k]};          ((k=k+1))
		d_secureretrieve[$i]=${detail[$k]}; ((k=k+1))		
		d_securedeliver[$i]=${detail[$k]};  ((k=k+1))
		d_pswd_auth[$i]=${detail[$k]};      ((k=k+1))		
		d_chgpswd[$i]="N"
		d_type[$i]=${ntcdma_type[$j]}
		;;

		ntmmdm )
		d_market[$i]=${detail[$k]};         ((k=k+1))
		d_tdir[$i]=${detail[$k]};           ((k=k+1))
		d_srcip[$i]=${detail[$k]};          ((k=k+1))
		d_srcid[$i]=${detail[$k]};          ((k=k+1))
		d_srcuser[$i]=${detail[$k]};        ((k=k+1))
		d_srcpswd[$i]=${detail[$k]};        ((k=k+1))
		d_srcdir[$i]=${detail[$k]};         ((k=k+1))
		d_ntopts[$i]=${detail[$k]};         ((k=k+1))
		d_tmadj[$i]=${detail[$k]};          ((k=k+1))
		d_mvsrc[$i]=${detail[$k]};          ((k=k+1))
		d_ddir[$i]=${detail[$k]};           ((k=k+1))
		d_secureretrieve[$i]=${detail[$k]}; ((k=k+1))		
		d_securedeliver[$i]=${detail[$k]};  ((k=k+1))
		d_pswd_auth[$i]=${detail[$k]};      ((k=k+1))		
		d_pvglist[$i]=${detail[$k]};        ((k=k+1))		
		d_chgpswd[$i]="N"
		d_type[$i]=${ntcdma_type[$j]}
        ;;


	    sdm )
		d_market[$i]=${detail[$k]};         ((k=k+1))
		d_tdir[$i]=${detail[$k]};           ((k=k+1))
		d_srcip[$i]=${detail[$k]};          ((k=k+1))
		d_srcid[$i]=${detail[$k]};          ((k=k+1))
		d_mtxid[$i]=${detail[$k]};          ((k=k+1))
		d_srcuser[$i]=${detail[$k]};        ((k=k+1))
		d_srcpswd[$i]=${detail[$k]};        ((k=k+1))
		d_srcdir[$i]=${detail[$k]};         ((k=k+1))
		d_cbmsdir[$i]=${detail[$k]};        ((k=k+1))
		d_srcopt[$i]=${detail[$k]};         ((k=k+1))
		d_ntopts[$i]=${detail[$k]};         ((k=k+1))
		d_tmadj[$i]=${detail[$k]};          ((k=k+1))
		d_colmult[$i]=${detail[$k]};        ((k=k+1))
		d_mvsrc[$i]=${detail[$k]};          ((k=k+1))
		d_sdmddir[$i]=${detail[$k]};        ((k=k+1))
		d_cbmddir[$i]=${detail[$k]};        ((k=k+1))
		d_secureretrieve[$i]=${detail[$k]}; ((k=k+1))		
		d_securedeliver[$i]=${detail[$k]};  ((k=k+1))
		d_pswd_auth[$i]=${detail[$k]};      ((k=k+1))
        d_mtxname[$i]=${detail[$k]};        ((k=k+1))
		d_chgpswd[$i]="N"
		d_type[$i]=${ntcdma_type[$j]}
		;;

	    uas )
		d_market[$i]=${detail[$k]};         ((k=k+1))
		d_tdir[$i]=${detail[$k]};           ((k=k+1))
		d_srcip[$i]=${detail[$k]};          ((k=k+1))
		d_srcid[$i]=${detail[$k]};          ((k=k+1))
		d_srcuser[$i]=${detail[$k]};        ((k=k+1))
		d_srcpswd[$i]=${detail[$k]};        ((k=k+1))
		d_srcdir[$i]=${detail[$k]};         ((k=k+1))
		d_nodetype[$i]=${detail[$k]};       ((k=k+1))
		d_nodename[$i]=${detail[$k]};       ((k=k+1))
		d_rptname[$i]=${detail[$k]};        ((k=k+1))
		d_timezone[$i]=${detail[$k]};       ((k=k+1))
		d_ntopts[$i]=${detail[$k]};         ((k=k+1))
		d_tmadj[$i]=${detail[$k]};          ((k=k+1))
		d_secureretrieve[$i]=${detail[$k]}; ((k=k+1))		
		d_securedeliver[$i]=${detail[$k]};  ((k=k+1))
		d_pswd_auth[$i]=${detail[$k]};      ((k=k+1))		
		d_chgpswd[$i]="N"
		d_type[$i]=${ntcdma_type[$j]}
		;;

	    mxpt )
		d_market[$i]=${detail[$k]};         ((k=k+1))
		d_tdir[$i]=${detail[$k]};           ((k=k+1))
		d_srcip[$i]=${detail[$k]};          ((k=k+1))
		d_mtxid[$i]=${detail[$k]};          ((k=k+1))
		d_srcuser[$i]=${detail[$k]};        ((k=k+1))
		d_srcpswd[$i]=${detail[$k]};        ((k=k+1))
		d_srcdir[$i]=${detail[$k]};         ((k=k+1))
		d_ntopts[$i]=${detail[$k]};         ((k=k+1))
		d_tmadj[$i]=${detail[$k]};          ((k=k+1))
		d_period[$i]=${detail[$k]};         ((k=k+1))
		d_secureretrieve[$i]=${detail[$k]}; ((k=k+1))		
		d_securedeliver[$i]=${detail[$k]};  ((k=k+1))
		d_pswd_auth[$i]=${detail[$k]};      ((k=k+1))		
		d_chgpswd[$i]="N"
		d_type[$i]=${ntcdma_type[$j]}
		d_srcid[$i]=${d_mtxid[$i]}
		;;

        mg )
    d_market[$i]=${detail[$k]};         ((k=k+1))
    d_tdir[$i]=${detail[$k]};           ((k=k+1))
    d_srcip[$i]=${detail[$k]};          ((k=k+1))
    d_srcid[$i]=${detail[$k]};          ((k=k+1))
    d_mtxid[$i]=${detail[$k]};          ((k=k+1))
    d_srcuser[$i]=${detail[$k]};        ((k=k+1))
    d_srcpswd[$i]=${detail[$k]};        ((k=k+1))
    d_srcdir[$i]=${detail[$k]};         ((k=k+1))
    d_ntopts[$i]=${detail[$k]};         ((k=k+1))
    d_tmadj[$i]=${detail[$k]};          ((k=k+1))
    d_mvsrc[$i]=${detail[$k]};          ((k=k+1))
    d_ddir[$i]=${detail[$k]};           ((k=k+1))
		d_secureretrieve[$i]=${detail[$k]}; ((k=k+1))		
		d_securedeliver[$i]=${detail[$k]};  ((k=k+1))
		d_pswd_auth[$i]=${detail[$k]};      ((k=k+1))		
    d_chgpswd[$i]="N"
    d_type[$i]=${ntcdma_type[$j]}
    ;;

	    pdsn16000 )
		d_market[$i]=${detail[$k]};         ((k=k+1))
		d_tdir[$i]=${detail[$k]};           ((k=k+1))
		d_srcip[$i]=${detail[$k]};          ((k=k+1))
		d_srcid[$i]=${detail[$k]};          ((k=k+1))
		d_srcuser[$i]=${detail[$k]};        ((k=k+1))
		d_srcpswd[$i]=${detail[$k]};        ((k=k+1))
		d_srcdir[$i]=${detail[$k]};         ((k=k+1))
		d_ntopts[$i]=${detail[$k]};         ((k=k+1))
		d_tmadj[$i]=${detail[$k]};          ((k=k+1))
		d_period[$i]=${detail[$k]};         ((k=k+1))
		d_secureretrieve[$i]=${detail[$k]}; ((k=k+1))		
		d_securedeliver[$i]=${detail[$k]};  ((k=k+1))
		d_pswd_auth[$i]=${detail[$k]};      ((k=k+1))		
    d_chgpswd[$i]="N"
		d_type[$i]=${ntcdma_type[$j]}
		;;
    		
	    * ) echo "${cmd}: ${ntcdma_type[$j]} is not valid Nortel type"
		exit 1
		;;
	    esac
		
	    # Compare password against the $FLEXDAPSWDFILE
	    compare_pswd_cfg ${ntcdma_type[$j]} ${d_market[$i]} \
		${d_srcid[$i]} ${d_srcuser[$i]} ${d_srcpswd[$i]}
	    if [ $? == 1 ] && \
	       ([ "${ntcdma_type[$j]}" != "mxpt" ] && \
                [ "${ntcdma_type[$j]}" != "pdsn16000" ])
	    then
		    typeset -l mkt_id=${d_market[$i]}
		    typeset -l id=${d_srcid[$i]}

		    diffpswd="$diffpswd ${mkt_id}.${id};$PSWDFILE"
		    echo "${cmd}: \"${mkt_id}.${id}\" password differs from the ${FLEXDAPSWDFILE}"
		    echo "${cmd}: The password for \"${mkt_id}.${id}\" in ${FLEXDAPSWDFILE} will remain\n"
	    fi

	    ((i=i+1))
	done

    ((j=j+1))
    done

    match=1
    for ems in ${omemslist[@]}
    do
        inlist=`echo ${cfgemslist[@]}`
        match=`is_firsttime "$ems" "$inlist"`
        if [ $match -eq 1 ]
        then
            echo "${cmd}: Warning: Both rncom or rnccfg configuration for $ems are required to set CONCAT_ON to \"Y\""
        fi
    done

    for ems in ${cfgemslist[@]}
    do
        inlist=`echo ${omemslist[@]}`
        match=`is_firsttime "$ems" "$inlist"`
        if [ $match -eq 1 ]
        then
            echo "${cmd}: Warning: Both rncom or rnccfg configuration for $ems are required to set CONCAT_ON to \"Y\""
        fi
    done

    export PASWD_NOT_MATCH="$diffpswd"
    
}

################################################################################
#                                                                              #
#                                Main Script                                   #
#                                                                              #
################################################################################

cmd=`basename $0`

test $# != 1 && usage

# Check the environment variable
if ([ -z $FLEXDAHOME ] || [ ! -d $FLEXDAHOME ])
then
    echo "${cmd}: FLEXDAHOME directory not found"
    exit 1
fi

cfgfile=$1

# cfg directory
CFGDIR=$FLEXDAHOME/cfg

# log directory
LOGDIR=$FLEXDAHOME/log

# data directory
DATADIR=$FLEXDAHOME/data

# backup directory
dtfmt=`date +$(echo :Y:m:d:H:M | tr ":" "%")`
SAVEDIR=$FLEXDAHOME/cfg/backup/$dtfmt
c5m="0,5,10,15,20,25,30,35,40,45,50,55"


#
# Icf info table
#
# NTPROCS   VDR DSVR NETYPE     DTYPE  PRD(M) ENTRY RETRY CRONTM        DIR       MON?
# -------   --- ---- ------     -----  ------ ----- ----- ------        -----     ----
set -A  NTPROCS                                                                      \
 bsmcfg      nt  ""   bsm       cfg     1440   10    5    "30,55|0"      dist      N \
 bsmmap      nt  ""   bsm       map       30  480    5    "20,50"        dist      N \
 bsmom       nt  ""   bsm       om        30  480   15    "25,55"        dist      N \
 bsmtrkr     nt  ""   bsm       trkr    1440   30    5    "0|9-12"       dist      N \
 mtxom       nt  ""   mtx       om        60  240   15    "35"           dist      Y \
 tables      nt  ""   mtx       tables    60  240    5    "2|0-19,22,23" dist      N \
 trkmem      nt  ""   mtx       trkmem    60  240    0    "22|0,1"       get       N \
 omshow      nt  ""   mtx       omshow     -    -    -    "|"            dist      N \
 ppcsta      nt  ""   ppc       sta       60  240   15    "5"            get       Y \
 rncom       nt  ""   rnc       om        30  240    0    "5,35"         dist      N \
 rnccfg      nt  ""   rnc       cfg     1440  240    5    "30|2-5"       dist      N \
 actlog      nt  ""   mtx       actlog    15  240    0    "0,15,30,45"   dist      N \
 caplog      nt  ""   mtx       caplog    15  240    0    "0,15,30,45"   dist      N \
 mtxtab      nt  ""   sdm       mtxtab    60  240    5    "2|0-19,22,23" dist      N \
 mtxlogs     nt  ""   mtx       logs      15  240    0    "0,15,30,45"   dist      N \
 pdsnom      nt  ""   pdsn      om        30  120    0    "5,35"         dist      N \
 faom        nt  ""   pdsn      faom      30  120    5    "5,35"         dist      N \
 haom        nt  ""   pdsn      haom      30  120    5    "5,35"         dist      N \
 pvgsta      nt  ""   pgmsc     pvgsta    15  240   15    "0,15,30,45"   dist      N \
 uspom       nt  ""   pgmsc     uspom      5  240    5    $c5m           dist      N \
 sdmom       nt  ""   pgmsc     sdmom     30  240   15    "15,45"        dist      N \
 ntmmdm      nt  ""   mg        ntmmdm    30  240   15    "15,45"        dist      N \
 uas         nt  ""   nt        uas       30  120    5    "5,35"         dist      N \
 mxptom      nt  ""   mxpt      om        60  240   10    "5"            dist      N \
 ntmsta      nt  ""   mg        ntmsta    30  120    5    "5,35"         dist      N \
 pdsn16000om nt  ""   pdsn16000 om        30  240   10    "5,35"         dist      N \
 bsmcsvs     nt  ""   bsm       csvs      30  240   10    "0,30"         dist      N \
 bsmcnfp     nt  ""   bsm       cnfp      30  240   10    "0,30"         dist      N

#
#  Mon info table
#
#  PROCNAME    PROGNAME        LOGDIR     DATADIR
#  ----------  --------        ------     -------
set -A mtxom_mon                                                \
   READER    nt_aft_reader     "get"      "|"                \
   PARSER    nt_mtxom_parse    "fmt"      "arch|src|dest|fail"

set -A ppcsta_mon                                               \
   PARSER    nt_ppcsta_parse   "fmt|dist" "arch|src|dest|fail|dist"

#  Number of NTPROCS attributes
NA_NTPROCS=11

# MTX Table lists
MTX_TABLES="C7RTESET|C7LKSET|CLLI|CDMACELL|CELLINV|TRKMEM|ADJCELL|PARTDATA|PARTDAT2|PWRCTRL|HOPARMS|VCHINV|CELLULAR|SBSINV"

# 1xEVDO Files list
EMSFILELIST[0]="*A10A11AuxA10PerfByPDSN*.dat"
EMSFILELIST[1]="*A10A11BytePacketCountByPDSN*.dat"
EMSFILELIST[2]="*A10A11BytePacketCountByRNC*.dat"
EMSFILELIST[3]="*A10A11PerfByPDSN*.dat"
EMSFILELIST[4]="*A10A11PerfByRNC*.dat"
EMSFILELIST[5]="*A10A11RegUpdatePerfByPDSN*.dat"
EMSFILELIST[6]="*A10A11SessionUpdatePerfByPDSN*.dat"
EMSFILELIST[7]="*A10ReconnectPerfByPDSN*.dat"
EMSFILELIST[8]="*A10ByteCountAndStatsBySlot*.dat"
EMSFILELIST[9]="*A10StatsByPCFIpAddress*.dat"
EMSFILELIST[10]="*A13PerfSourceRNC*.dat"
EMSFILELIST[11]="*A16PerfByRemoteRNC*.dat"
EMSFILELIST[12]="*A16PerfSourceRNC*.dat"
EMSFILELIST[13]="*A16PerfSourceRNCBySlot*.dat"
EMSFILELIST[14]="*ActiveConnections*.dat"
EMSFILELIST[15]="*ActiveRFLinks*.dat"
EMSFILELIST[16]="*AirlinkResourceAllocation*.dat"
EMSFILELIST[17]="*CCHStatsSectorCarrier*.dat"
EMSFILELIST[18]="*CPUUtilization*.dat"
EMSFILELIST[19]="*DoSPerSlot_*.dat"
EMSFILELIST[20]="*HHO_Inhibit_*.dat"
EMSFILELIST[21]="*HHOInhibit_*.dat"
EMSFILELIST[22]="*InterfaceUtilizationByPort*.dat"
EMSFILELIST[23]="*ResourceAllocationPerfByRNC*.dat"
EMSFILELIST[24]="*Rn_ISSHO_TrafficPerRNC_*.dat"
EMSFILELIST[25]="*Rn_ISSHO_TrafficTotal_*.dat"
EMSFILELIST[26]="*RnISSHOTrafficTotal*.dat"
EMSFILELIST[27]="*RnISSHOTrafficPerRNC_*.dat"
EMSFILELIST[28]="*RNCBytePacketCountByRNC*.dat"
EMSFILELIST[29]="*RNCBytePacketCountBySlot*.dat"
EMSFILELIST[30]="*RNCResourceControl*.dat"
EMSFILELIST[31]="*Rn0ConnectionResourceUsageHistogramPerSector_*.dat"
EMSFILELIST[32]="*RnAConnectionResourceUsageHistogramPerSector_*.dat"
EMSFILELIST[33]="*RnConnectionResourceUsageHistogramPerModem*.dat"
EMSFILELIST[34]="*RnConnectionResourceUsageHistogramPerSector*.dat"
EMSFILELIST[35]="*RNCPerfByRNC*.dat"
EMSFILELIST[36]="*RNCPerfBySectorCarrier*.dat"
EMSFILELIST[37]="*RNCPerfBySlot*.dat"
EMSFILELIST[38]="*RNCPerfExtnByRNC*.dat"
EMSFILELIST[39]="*RNCPerfExtnBySlot*.dat"
EMSFILELIST[40]="*RNCRvsPacketSizeBySlot*.dat"
EMSFILELIST[41]="*RNC_ISSHO_PerfBySecondarySectorCarrier*.dat"
EMSFILELIST[42]="*RNCISSHOPerfBySecondarySectorCarrier*.dat"
EMSFILELIST[43]="*RncISSHOPerfBySecondarySectorCarrier*.dat"
EMSFILELIST[44]="*RNCFwdPacketSizeBySlot*.dat"
EMSFILELIST[45]="*RNCFwdPacketBySlot*.dat"
EMSFILELIST[46]="*RNCPerSessionConfig*.dat"
EMSFILELIST[47]="*RNCThruputBytesBySlot*.dat"
EMSFILELIST[48]="*RNC_ResourceControl*.dat"
EMSFILELIST[49]="*RNSM_LoadBalancing_*.dat"
EMSFILELIST[50]="*RNSMLoadBalancing_*.dat"
EMSFILELIST[51]="*RnSector_AchStats_*.dat"
EMSFILELIST[52]="*RnSector_CchStats_*.dat"
EMSFILELIST[53]="*RnSector_FtcStats*.dat"
EMSFILELIST[54]="*RnSector_Perf_1*.dat"
EMSFILELIST[55]="*RnSector_Perf_2*.dat"
EMSFILELIST[56]="*RnSector_RtcStats*.dat"
EMSFILELIST[57]="*RnSector_SignalQuality_*.dat"
EMSFILELIST[58]="*RnSectorCchStats*.dat"
EMSFILELIST[59]="*RnSectorFtcStats*.dat"
EMSFILELIST[60]="*RnSectorPerf_*.dat"
EMSFILELIST[61]="*RnSectorPerf2*.dat"
EMSFILELIST[62]="*RnSectorRtcStats_*.dat"
EMSFILELIST[63]="*RnSectorSignalQuality_*.dat"
EMSFILELIST[64]="*SectorCarrier_ACStats_*.dat"
EMSFILELIST[65]="*TermAuthPerfByAAAServer*.dat"
EMSFILELIST[66]="*TermAuthPerfByRNC*.dat"
EMSFILELIST[67]="*TermAuthPerfBySlot*.dat"
EMSFILELIST[68]="*ThruputSectorCarrier_*.dat"
EMSFILELIST[69]="*NISRPerf_*.dat"
EMSFILELIST[70]="*QoS_CommonPerfBySlot_*.dat"
EMSFILELIST[71]="*QoSCommonPerfBySlot_*.dat"
EMSFILELIST[72]="*QoSPerfBySlot_*.dat"
EMSFILELIST[73]="*QoSTrafficTypePerf*.dat"
EMSFILELIST[74]="*InterUserBEPriChangePerfByRNC*.dat"
EMSFILELIST[75]="*InterUserBEPriLevelPerfPerRnc*.dat"
EMSFILELIST[76]="*MeasurableInstrumentation*.dat"
EMSFILELIST[77]="*OvrldCtrlCardResourceUtilization*.dat"
EMSFILELIST[78]="*PerModemFlowUsage*.dat"
EMSFILELIST[79]="*QoSPerfBySectorByClass*.dat"
EMSFILELIST[80]="*QoSPerfBySlotByTrafficType*.dat"
EMSFILELIST[81]="*QoSTxPriorityUtilization*.dat"
EMSFILELIST[82]="*RevAMultiUserTXFormats*.dat"
EMSFILELIST[83]="*RevASingleUserTXFormats*.dat"
EMSFILELIST[84]="*RNCOvldCtrl*.dat"
EMSFILELIST[85]="*RNCPageOvldCtrl*.dat"
EMSFILELIST[86]="*RnDrcEmSectorPerf*.dat"
EMSFILELIST[87]="*RnSectorPerfDelIUBE*.dat"
EMSFILELIST[88]="*RnSectorPerfFTCIUBE*.dat"
EMSFILELIST[89]="*RnSectorPerfRTCIUBE*.dat"
EMSFILELIST[90]="*ROTPerfBySectorByClass*.dat"
EMSFILELIST[91]="*SlotUtilPerfBySectorByClass*.dat"
EMSFILELIST[92]="*TrafficTypePerfBySectorClass*.dat"
EMSFILELIST[93]="*BackhaulDelayHistogram*.dat"
EMSFILELIST[94]="*BackhaulDelayStatistics*.dat"
EMSFILELIST[95]="*ControlCHSubSyncAsyncSlotUtilization*.dat"
EMSFILELIST[96]="*QoSPerfByConstraintCheck*.dat"
EMSFILELIST[97]="*QoSPerfByDriverFlow*.dat"
EMSFILELIST[98]="*QoSPerfByTrafficTypeConstraintCheck*.dat"
EMSFILELIST[99]="*QosRmbAocConstrBasedPerfBySC*.dat"
EMSFILELIST[100]="*QosRmbAocQueueStatsPerfBySc*.dat"
EMSFILELIST[101]="*QosRmbAocRotPerfBySC*.dat"
EMSFILELIST[102]="*RevAPhyMac*.dat"
EMSFILELIST[103]="*Rn0ConnectionResourceUsageHistogramPerModem*.dat"
EMSFILELIST[104]="*RnAConnectionResourceUsageHistogramPerModem*.dat"
EMSFILELIST[105]="*RnSectorAchRate*.dat"
EMSFILELIST[106]="*RnSectorAchSize*.dat"
EMSFILELIST[107]="*SectorDelay*.dat"
EMSFILELIST[108]="*T1E1BackHaul*.dat"
EMSFILELIST[108]="*TrafficTypePerfBySectorClass*.dat"
EMSFILELIST[109]="*RNCClusterLB*.dat"
EMSFILELIST[110]="*RnACHcapsuleCCHSyncSubSyncAsyncSlotUtilization*.dat"
EMSFILELIST[111]="*TCAACHCCHUtilizationDurations*.dat"
EMSFILELIST[112]="*QoSCommonPerfBySlot*.dat"                  
EMSFILELIST[113]="*QoSPerfBySlot*.dat"                        
EMSFILELIST[114]="*QoSRxPriorityUtilization*.dat"            
EMSFILELIST[115]="*QoSTrafficTypePerf*.dat"
EMSFILELIST[116]="*RNCEgressThroughputBySlot*.dat"
EMSFILELIST[117]="*RNCIngressThroughputBySlot*.dat"
EMSFILELIST[118]="*RNCOvldCtrlThresholdCrossing*.dat"
EMSFILELIST[119]="*RxPriorityThreshold*.dat"
EMSFILELIST[120]="*T1E1BackHaul_R7.0*.dat"
EMSFILELIST[121]="*T1E1BackHaul_R8.0*.dat"

# DOM Configuration file list
DOMCFGFILELIST="dom pn if pdsn"
# DOM Configuration file list wheb concat is on
CONCATDOMCFGFILELIST="dom pn if pdsn ?andidaternc?uery"

# 1xEVDO RNC Files list for file concatenation (R8.0 and above)
RNCFILELIST[0]="*A10A11AuxA10PerfByPDSN*.dat"
RNCFILELIST[1]="*A10A11BytePacketCountByPDSN*.dat"
RNCFILELIST[2]="*A10A11BytePacketCountByRNC*.dat"
RNCFILELIST[3]="*A10A11PerfByPDSN*.dat"
RNCFILELIST[4]="*A10A11PerfByRNC*.dat"
RNCFILELIST[5]="*A10A11RegUpdatePerfByPDSN*.dat"
RNCFILELIST[6]="*A10A11SessionUpdatePerfByPDSN*.dat"
RNCFILELIST[7]="*A10ReconnectPerfByPDSN*.dat"
RNCFILELIST[8]="*A13PerfSourceRNC*.dat"
RNCFILELIST[9]="*A16PerfByRemoteRNC*.dat"
RNCFILELIST[10]="*A16PerfSourceRNC*.dat"
RNCFILELIST[11]="*A16PerfSourceRNCBySlot*.dat"
RNCFILELIST[12]="*CPUUtilization*.dat"
RNCFILELIST[13]="*DoSPerSlot_*.dat"
RNCFILELIST[14]="*HHOInhibit_*.dat"
RNCFILELIST[15]="*InterfaceUtilizationByPort*.dat"
RNCFILELIST[16]="*InterUserBEPriChangePerfByRNC*.dat"
RNCFILELIST[17]="*InterUserBEPriLevelPerfPerRnc*.dat"
RNCFILELIST[18]="*MeasurableInstrumentation*.dat"
RNCFILELIST[19]="*NISRPerf_*.dat"
RNCFILELIST[20]="*OvrldCtrlCardResourceUtilization*.dat"
RNCFILELIST[21]="*QoSCommonPerfBySlot_*.dat"
RNCFILELIST[22]="*QoSPerfBySlot_*.dat"
RNCFILELIST[23]="*QoSPerfBySlotByTrafficType*.dat"
RNCFILELIST[24]="*QoSTrafficTypePerf*.dat"
RNCFILELIST[25]="*QoSTxPriorityUtilization*.dat"
RNCFILELIST[26]="*RNCBytePacketCountByRNC*.dat"
RNCFILELIST[27]="*RNCBytePacketCountBySlot*.dat"
RNCFILELIST[28]="*RNCClusterLB*.dat"
RNCFILELIST[29]="*RNCEgressThroughputBySlot*.dat"
RNCFILELIST[30]="*RNCFwdPacketSizeBySlot*.dat"
RNCFILELIST[31]="*RNCIngressThroughputBySlot*.dat"
RNCFILELIST[32]="*RNCOvldCtrl*.dat"
RNCFILELIST[33]="*RNCOvldCtrlThresholdCrossing*.dat"
RNCFILELIST[34]="*RNCPageOvldCtrl*.dat"
RNCFILELIST[35]="*RNCPerfByRNC*.dat"
RNCFILELIST[36]="*RNCPerfBySectorCarrier*.dat"
RNCFILELIST[37]="*RNCPerfBySlot*.dat"
RNCFILELIST[38]="*RNCPerfExtnByRNC*.dat"
RNCFILELIST[39]="*RNCPerfExtnBySlot*.dat"
RNCFILELIST[40]="*RNCPerSessionConfig*.dat"
RNCFILELIST[41]="*RNCResourceControl*.dat"
RNCFILELIST[42]="*RNCRvsPacketSizeBySlot*.dat"
RNCFILELIST[43]="*RNSMLoadBalancing_*.dat"
RNCFILELIST[44]="*TermAuthPerfByAAAServer*.dat"
RNCFILELIST[45]="*TermAuthPerfByRNC*.dat"
RNCFILELIST[46]="*TermAuthPerfBySlot*.dat"

# 1xEVDO DOM Files list for file concatenation (R8.0 and above)
DOMFILELIST[0]="*PerModemFlowUsageHistogram*.dat"
DOMFILELIST[1]="*PerModemFlowUsageIUBE*.dat"
DOMFILELIST[2]="*PerModemFlowUsageTT*.dat"
DOMFILELIST[3]="*RevAMultiUserTXFormats*.dat"
DOMFILELIST[4]="*RevASingleUserTXFormats*.dat"
DOMFILELIST[5]="*Rn0ConnectionResourceUsageHistogramPerSector_*.dat"
DOMFILELIST[6]="*RnACHcapsuleCCHSyncSubSyncAsyncSlotUtilization*.dat"
DOMFILELIST[7]="*RnAConnectionResourceUsageHistogramPerSector_*.dat"
DOMFILELIST[8]="*RNCISSHOPerfBySecondarySectorCarrier*.dat"
DOMFILELIST[9]="*RnDrcEmSectorPerf*.dat"
DOMFILELIST[10]="*RnISSHOTrafficPerRNC_*.dat"
DOMFILELIST[11]="*RnISSHOTrafficTotal*.dat"
DOMFILELIST[12]="*RnSectorCchStats*.dat"
DOMFILELIST[13]="*RnSectorFtcStats*.dat"
DOMFILELIST[14]="*RnSectorPerf_*.dat"
DOMFILELIST[15]="*RnSectorPerfDelIUBE*.dat"
DOMFILELIST[16]="*RnSectorPerfFTCIUBE*.dat"
DOMFILELIST[17]="*RnSectorPerfRTCIUBE*.dat"
DOMFILELIST[18]="*RnSectorRtcStats_*.dat"
DOMFILELIST[19]="*RnSectorSignalQuality_*.dat"
DOMFILELIST[20]="*ROTPerfBySectorByClass*.dat"
DOMFILELIST[21]="*SlotUtilPerfBySectorByClass*.dat"
DOMFILELIST[22]="*TCAACHCCHUtilizationDurations*.dat"
DOMFILELIST[23]="*TrafficTypePerfBySectorClass*.dat"
DOMFILELIST[24]="*T1E1BackHaul*.dat"
DOMFILELIST[25]="*RncISSHOPerfBySecondarySectorCarrier*.dat"
DOMFILELIST[26]="*Rn0ConnectionResourceUsageHistogramPerModem*.dat"
DOMFILELIST[27]="*RnAConnectionResourceUsageHistogramPerModem*.dat"

# Password change script info
P_PRD=43200
P_ENTRY=30
P_RETRY=5
P_HR=9


# Initialize local variable
unset d_market d_tdir d_srcip d_datasrvid d_srcid d_mtxid d_bsmid d_srcdir
unset d_cfgdir d_bscdir d_srcuser d_srcpswd d_nogrps d_port d_mtxtbls
unset d_chgpswd d_moncfg unset d_ashell d_bshell
unset d_ntopts d_tmadj d_monopt d_omfnames d_omshowinfo
unset d_nodeid d_rdfcfg d_bdfdel d_cbrscfg d_cbrsname
unset d_bip d_bid d_buser d_bpswd d_bdir
unset d_nodetype d_nodename d_rptname d_timezone
unset d_period d_rnccfgid
unset d_cbmsdir d_srcopt d_colmult d_mvsrc d_sdmddir d_cbmddir
unset d_ddir 
unset d_csvsdir d_cnfpdir
unset d_secureretrieve d_securedeliver d_pswd_auth
unset d_cbmpassthrough d_cbmip d_cbmuser d_cbmpswd
unset d_rmt_cmprs d_scratcharea d_dombatchsize d_domcollection
unset d_allemslist d_concaton d_cfgtarget
unset d_pvglist

# Validate the setup config file and populate array
check_cfg_file $cfgfile

# Open a file descriptor for the cron file
cron_file=$CFGDIR/$HOST.ntcdma.cron

# SEAde66809 - Simplify the setup process when adding new network elements
fd_cron=4
create_file $fd_cron $cron_file
# end SEAde66809 - Simplify the setup process when adding new network elements

# Loop through each type and make the setup

ans=0
j=0
cfgrnccfg_mi=0
cfgrncom_mi=5
while (($j < ${#d_market[*]}))
do
    p=0
    unset nt_opt

    set -A nt_opt $(echo ${d_ntopts[$j]} | tr "," " ")
    while (($p < ${#nt_opt[*]}))
    do

        # Get common information for each ntcdma option
        unset c_optname c_vendor c_datasrv c_netype c_dtype
        unset c_period c_entries c_retries c_crontm c_direct c_monproc
        unset found nename
        unset m_procname m_progname m_ldir m_ddir mlogdir mdatadir
        unset tlogdir tdatadir
        
        # Validate option type
        found=0
        x=0
        while (($x < ${#NTPROCS[*]}))
        do
            if [ "${nt_opt[$p]}" == "${NTPROCS[$x]}" ]
            then
                found=1;
                break;
            else
                ((x=x+$NA_NTPROCS))
            fi
        done

        if [ $found == 0 ]
        then
            echo "${cmd}: ${nt_opt[$p]} is not a supported ntcdma option type"
            ((p=p+1))
            continue
        fi

        # Get the NTPROCS common info
        c_optname=${NTPROCS[$x]}; ((x=x+1))
        c_vendor=${NTPROCS[$x]};  ((x=x+1))
        c_datasrv=${NTPROCS[$x]}; ((x=x+1))
        c_netype=${NTPROCS[$x]};  ((x=x+1))
        c_dtype=${NTPROCS[$x]};   ((x=x+1))
        c_period=${NTPROCS[$x]};  ((x=x+1))
        c_entries=${NTPROCS[$x]}; ((x=x+1))
        c_retries=${NTPROCS[$x]}; ((x=x+1))
        set -A c_crontm $(echo ${NTPROCS[$x]} | tr "|" " "); ((x=x+1))
        c_direct=${NTPROCS[$x]};  ((x=x+1))
        typeset -u c_monproc=${NTPROCS[$x]}; ((x=x+1))

        # Create OMSHOW list
        if [ ${c_optname} == "omshow" ]
        then
            set -A d_omshowinfo ${d_omshowinfo[*]} ${d_srcid[$j]}
            ((p=p+1))
            continue
        fi

        # Create FlexDA monitor log and data directories
        if [ "${c_monproc}" == "Y" ]
        then
            n=0
            set -A d_monopt "${d_monopt} $c_optname"
            set -A mon_detail $(eval echo \$\{$c_optname\_mon[*]})

            if ([ ${#mon_detail[*]} == 0 ] || \
                [ `expr ${#mon_detail[*]} % 4` != 0 ])
            then
                echo "${cmd}: ${c_optname}_mon not specified properly"
                exit 1
            fi

            i=0
            while (($n < ${#mon_detail[*]}))
            do
                m_procname=${mon_detail[$n]};   ((n=n+1))
                m_progname=${mon_detail[$n]};   ((n=n+1))
                m_ldir=${mon_detail[$n]};     ((n=n+1))
                m_ddir=${mon_detail[$n]};     ((n=n+1))

                for dir in $(echo $m_ldir | tr "|" " ")
                do
                    set -A mlogdir "${mlogdir[*]} ${dir}"
                done

                for dir in $(echo $m_ddir | tr "|" " ")
                do
                    set -A mdatadir "${mdatadir[*]} ${dir}"
                done

                ((i=i+1))
            done
        fi

        nename=${c_netype}${d_srcid[$j]}
        typeset -l jobname=${d_market[$j]}.${nename}.${c_dtype}.${c_direct}
        if [ "${c_datasrv}" != "" ]
        then
            datasrv_field="_${c_datasrv}${d_datasrvid[$j]}"
        else
            datasrv_field=""
        fi

        typeset -l edir=${d_market[$j]}${datasrv_field}_${nename}
        typeset -l tdir=${c_dtype}

        #
        # Make required directories
        #

        tlogdir=${LOGDIR}/${edir}/${tdir}
        tdatadir=${DATADIR}/${edir}/${tdir}

        #
        # Append monitor log and data directory
        #

        if [ -n "${mlogdir[*]}" ]
        then
            unset ldir
            for dir in ${mlogdir[*]}; do
                ldir="$ldir $tlogdir/$dir"
            done

            tlogdir="$tlogdir $ldir"
        fi

        if [ -n "${mdatadir[*]}" ]
        then
            unset ddir
            for dir in ${mdatadir[*]}; do
                ddir="$ddir $tdatadir/$dir"
            done

            tdatadir="$tdatadir $ddir"
        fi

        for dir in $tlogdir $tdatadir
        do
            if [ ! -d $dir ]
            then
                echo "${cmd}: making directory $dir"
                mkdir -p $dir
            fi
        done


        #
        # Creates .chk and .icf file
        #

        typeset -l chkfname=$jobname.chk
        typeset -l icffname=$jobname.icf

		# SEAde66809 - Simplify the setup process when adding new network elements
		if [ ! -f $LOGDIR/$chkfname ]
	    then
	        ans=1
	    else
	        ans=0
	    fi
		# end SEAde66809 - Simplify the setup process when adding new network elements

        if [ "$c_optname" == "ppcsta" ] || [ "$c_optname" == "mxptom" ] || \
	   [ "$c_optname" == "pdsn16000om" ]
        then
            c_period=${d_period[$j]}
        fi

        # Set checkpoint interval to 2 hours for rncom only when REMOTE_COMPRESSION
        # was turned on. and CONCAT_ON is turn off
        if [ "$c_optname" == "rncom" ] && [ "${d_rmt_cmprs[$j]}" == "Y" ] && [ "${d_concaton[$j]}" == "N" ]
        then
            c_period=120
        fi

        if [ ans -eq 1 ]
        then
	    	create_file 0 $chkfname
            icf_create -n $c_entries -r $c_retries \
                $c_period $LOGDIR/$chkfname
        fi

        # SEAde66809 - Simplify the setup process when adding new network elements
        fd=5
	    create_file $fd $CFGDIR/$icffname

            #
            # Prints ICF header info
            #

            typeset -u title="$c_vendor $c_netype$c_dtype Data Transfer"
            print_common_icf $fd "$title" "${d_market[$j]}" "$c_netype" \
                "${d_srcid[$j]}" "$c_dtype" "$c_direct" "${d_rmt_cmprs[$j]}" "${d_concaton[$j]}"

            case  $c_optname in
                bsmcfg )
                    print_bsmcfg_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]} \
                        ${d_srcpswd[$j]} ${d_srcid[$j]} ${d_cfgdir[$j]}  \
                        ${d_mtxid[$j]} ${d_bsmid[$j]} ${d_tmadj[$j]}     \
			                  ${d_secureretrieve[$j]}  ${d_securedeliver[$j]}  \
                        ${d_pswd_auth[$j]} ${lhost[1]}
                        ;;

                bsmmap )
                    print_bsmmap_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]} \
                        ${d_srcpswd[$j]} ${d_srcid[$j]} ${d_mtxid[$j]}   \
                        ${d_bsmid[$j]} ${d_tmadj[$j]}                    \
			                  ${d_secureretrieve[$j]}  ${d_securedeliver[$j]}  \
                        ${d_pswd_auth[$j]} ${lhost[1]}
                        ;;

                bsmom )
                    print_bsmom_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]} \
                        ${d_srcpswd[$j]} ${d_srcid[$j]} ${d_srcdir[$j]} \
                        ${d_bscdir[$j]} ${d_mtxid[$j]} ${d_bsmid[$j]}   \
                        ${d_omfnames[$j]} ${d_tmadj[$j]}                \
			                  ${d_secureretrieve[$j]}  ${d_securedeliver[$j]} \
                        ${d_pswd_auth[$j]} ${lhost[1]}
                        ;;
                        
                bsmcnfp )
                    print_bsmcnfp_icf  $fd  ${d_srcip[$j]} ${d_srcid[$j]} \
                        ${d_bsmid[$j]} ${d_mtxid[$j]} ${d_srcuser[$j]}    \
                        ${d_srcpswd[$j]} ${d_cnfpdir[$j]} ${d_tmadj[$j]}  \
			                  ${d_secureretrieve[$j]}  ${d_securedeliver[$j]}   \
                        ${d_pswd_auth[$j]} ${lhost[1]}
                        ;;                        
                        
                bsmcsvs )
                    print_bsmcsvs_icf  $fd  ${d_srcip[$j]} ${d_srcid[$j]} \
                        ${d_bsmid[$j]} ${d_mtxid[$j]} ${d_srcuser[$j]}    \
                        ${d_srcpswd[$j]} ${d_csvsdir[$j]} ${d_tmadj[$j]}  \
			                  ${d_secureretrieve[$j]}  ${d_securedeliver[$j]}   \
                        ${d_pswd_auth[$j]} ${lhost[1]}
                        ;;                        

                bsmtrkr )
                    print_bsmtrkr_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]} \
                        ${d_srcpswd[$j]} ${d_srcid[$j]} ${d_srcdir[$j]}   \
                        ${d_bsmid[$j]} ${d_mtxid[$j]} ${d_tmadj[$j]}      \
			                  ${d_secureretrieve[$j]}  ${d_securedeliver[$j]}   \
                        ${d_pswd_auth[$j]} ${lhost[1]}
                        ;;
                        
                mtxom )
                    print_mtxom_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]} \
                        ${d_srcpswd[$j]} ${d_srcid[$j]} ${d_srcid[$j]}  \
                        ${d_mtxid[$j]} ${d_tmadj[$j]}                   \
                        ${d_securedeliver[$j]} ${d_pswd_auth[$j]}       \
                        ${lhost[1]}
                        ;;

                tables )
                    print_tables_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]} \
                        ${d_srcpswd[$j]}  ${d_srcid[$j]} $MTX_TABLES     \
                        ${d_tmadj[$j]}  ${d_cbmpassthrough[$j]} ${d_cbmip[$j]} \
                        ${d_cbmuser[$j]} ${d_cbmpswd[$j]} \
                        ${d_secureretrieve[$j]} ${d_securedeliver[$j]}   \
                        ${d_pswd_auth[$j]} ${lhost[1]}
                        ;;

                trkmem )
                    print_trkmem_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]} \
		        ${d_srcpswd[$j]} ${d_srcid[$j]} ${d_tmadj[$j]}   \
			${d_secureretrieve[$j]}  ${d_securedeliver[$j]}  \
			${d_pswd_auth[$j]} ${lhost[1]} 
		        ;;

                ntmsta )
                    print_ntmsta_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]}      \
                        ${d_srcpswd[$j]} ${d_srcid[$j]} ${d_mtxid[$j]}        \
                        ${d_srcdir[$j]} ${d_mvsrc[$j]} ${d_ddir[$j]}          \
                        ${d_tmadj[$j]} ${d_secureretrieve[$j]}                \
                        ${d_securedeliver[$j]} ${d_pswd_auth[$j]} ${lhost[1]}
                        ;;
              
                ppcsta )
                    print_ppcstaget_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]} \
                        ${d_srcpswd[$j]} ${d_srcid[$j]} ${d_nodeid[$j]}     \
                        ${d_srcdir[$j]} ${d_datasrvid[$j]} ${d_tmadj[$j]}   \
                        ${d_secureretrieve[$j]} ${d_pswd_auth[$j]}          \
                        ${lhost[1]}

                    typeset -l jobname=${d_market[$j]}.${nename}.${c_dtype}.dist
                    tdatadir=`echo $tdatadir|sed "s/ .*$//"`
                    typeset -l disticffname=$jobname.icf
                    typeset -l stasrcdir=${tdatadir}/src
                    typeset -l stalocaldir=${tdatadir}/dist

                    # SEAde66809 - Simplify the setup process when adding new network elements
                    fd_dist=6
                    create_file $fd_dist $CFGDIR/$disticffname
                    # end SEAde66809 - Simplify the setup process when adding new network elements


                    print_ppcstadist_icf $fd_dist "${d_market[$j]}"           \
                        "$c_netype" "${d_srcid[$j]}" "$c_dtype" "$c_direct"   \
                        ${d_securedeliver[$j]} ${d_pswd_auth[$j]} ${lhost[1]}

                    print_thost_icf $fd_dist ${thost[1]} ${thost[2]} \
                        ${thost[3]} ${d_tdir[$j]}
                        ;;

                faom|haom|pdsnom )
                    print_pdsnom_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]}  \
                        ${d_srcpswd[$j]} ${d_srcid[$j]} ${d_srcdir[$j]}   \
                        $c_optname ${d_tmadj[$j]} ${d_secureretrieve[$j]} \
                        ${d_securedeliver[$j]} ${d_pswd_auth[$j]}         \
                        ${lhost[1]}
                        ;;
                rncom )
                    if [ ${d_concaton[$j]} == "Y" ] 
                    then
                        if [ ${d_domcollection[$j]} == "Y" ]
                        then
                            filelist=`echo ${RNCFILELIST[@]} ${DOMFILELIST[@]}`
                        else
                            filelist=`echo ${RNCFILELIST[@]}`
                        fi
                    else
                        filelist=`echo ${EMSFILELIST[@]}`
                    fi
                    set -A concatlist $filelist

                    print_rncom_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]}    \
                        ${d_srcpswd[$j]} ${d_datasrvid[$j]} ${d_srcid[$j]} \
                        ${d_srcdir[$j]} "${filelist[*]}" ${d_tmadj[$j]} \
                        ${d_scratcharea[$j]} ${d_secureretrieve[$j]}       \
                        ${d_securedeliver[$j]} ${d_pswd_auth[$j]}          \
                        ${d_rmt_cmprs[$j]} ${d_dombatchsize[$j]}           \
                        ${d_domcollection[$j]} ${lhost[1]}          
                        ;;

                rnccfg )
                    print_rnccfg_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]}      \
                        ${d_srcpswd[$j]} ${d_datasrvid[$j]} ${d_rnccfgid[$j]} \
                        ${d_srcdir[$j]} ${d_concaton[$j]} ${d_tmadj[$j]}    \
                        ${d_secureretrieve[$j]} ${d_securedeliver[$j]}        \
                        ${d_pswd_auth[$j]} ${d_allemslist[$j]}              \
                        ${d_cfgtarget[$j]} ${lhost[1]}
                        ;;

                mtxlogs | actlog | caplog )
                    print_mtxlog_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]} \
                        ${d_srcpswd[$j]} ${d_srcid[$j]} ${c_optname}     \
                        ${d_tmadj[$j]} ${d_secureretrieve[$j]}           \
                        ${d_securedeliver[$j]} ${d_pswd_auth[$j]} ${lhost[1]}
                        ;;

                mtxtab )
                    print_mtxtab_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]}       \
                        ${d_srcpswd[$j]}  ${d_srcid[$j]} ${d_mtxid[j]}         \
                        ${d_srcdir[$j]} ${d_tmadj[$j]} ${d_secureretrieve[$j]} \
                        ${d_securedeliver[$j]} ${d_pswd_auth[$j]} ${lhost[1]}
                        ;;

                pvgsta )
                    print_pvgsta_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]}     \
                        ${d_srcpswd[$j]} ${d_mscid[$j]} ${d_datasrvid[$j]}   \
                        ${d_nodeid[$j]} ${d_srcid[$j]} ${d_srcdir[$j]}       \
                        ${d_tmadj[$j]} ${d_secureretrieve[$j]}               \
                        ${d_securedeliver[$j]} ${d_pswd_auth[$j]} ${lhost[1]}
                        ;;

                sdmom )
                    print_sdmom_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]} ${d_srcpswd[$j]} \
                        ${d_srcid[$j]} ${d_mtxid[$j]} ${d_srcdir[$j]}         \
                        ${d_cbmsdir[$j]} ${d_srcopt[$j]} ${d_colmult[$j]}     \
                        ${d_mvsrc[$j]} ${d_sdmddir[$j]} ${d_cbmddir[$j]}      \
                        ${d_tmadj[$j]} ${d_secureretrieve[$j]}                \
                        ${d_securedeliver[$j]} ${d_pswd_auth[$j]} ${lhost[1]} \
                        ${d_mtxname[$j]}
                        ;;

                ntmmdm )
                    print_ntmmdm_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]}     \
                        ${d_srcpswd[$j]} ${d_srcid[$j]} ${d_srcdir[$j]}      \
                        ${d_mvsrc[$j]} ${d_ddir[$j]} ${d_tmadj[$j]}          \
                        ${d_secureretrieve[$j]} ${d_securedeliver[$j]}       \
                        ${d_pswd_auth[$j]} ${lhost[1]} ${d_pvglist[$j]}
                        ;;

                uspom )
                    print_uspom_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]}       \
                        ${d_srcpswd[$j]} ${d_srcid[$j]} ${d_srcdir[$j]}       \
                        ${d_bip[$j]} ${d_buser[$j]} ${d_bpswd[$j]}            \
                        ${d_bid[$j]} ${d_bsdir[$j]} ${d_nodeid[$j]}           \
                        ${d_mscid[$j]} ${d_tmadj[$j]} ${d_secureretrieve[$j]} \
                        ${d_securedeliver[$j]} ${d_pswd_auth[$j]} ${lhost[1]}
                        ;;

                uas )
                    print_uas_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]}        \
                        ${d_srcpswd[$j]} ${d_srcdir[$j]} ${d_nodetype[$j]}   \
                        ${d_nodename[$j]} ${d_rptname[$j]} ${d_timezone[$j]} \
                        ${d_tmadj[$j]} ${d_secureretrieve[$j]}               \
                        ${d_securedeliver[$j]} ${d_pswd_auth[$j]} ${lhost[1]}
                        ;;

                mxptom )
                    print_mxpt_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]}        \
                        ${d_srcpswd[$j]} ${d_srcdir[$j]} ${d_mtxid[$j]}       \
                        ${d_tmadj[$j]} ${d_secureretrieve[$j]}                \
                        ${d_securedeliver[$j]} ${d_pswd_auth[$j]} ${lhost[1]}
                        ;;

                pdsn16000om )
                    print_pdsn16000om_icf $fd ${d_srcip[$j]} ${d_srcuser[$j]} \
		    	              ${d_srcpswd[$j]} ${d_srcdir[$j]} ${d_srcid[$j]}       \
			                  ${d_tmadj[$j]} ${d_secureretrieve[$j]}                \
                        ${d_securedeliver[$j]} ${d_pswd_auth[$j]} ${lhost[1]}
                        ;;


                * ) echo "${cmd}: $c_optname not supported";;
             esac


             #
             # Prints Prospect target host info
             #

             print_thost_icf $fd ${thost[1]} ${thost[2]} ${thost[3]} \
		 ${d_tdir[$j]}

         # end SEAde66809 - Simplify the setup process when adding new network elements

         #
         # Add cron entry in crontab file
         #

         mi=${c_crontm[0]:-*}
         hr=${c_crontm[1]:-*}
         dm=${c_crontm[2]:-*}
         my=${c_crontm[3]:-*}
         dw=${c_crontm[4]:-*}

         tlogdir=`echo $tlogdir|sed "s/ .*$//"`

	 #
	 # Data collection periods for ppcsta configurable
	 # The crontab time should be i*$period + 5 minutes
	 #
	 if [ "$c_optname" == "ppcsta" ] || [ "$c_optname" == "mxptom" ] || \
	    [ "$c_optname" == "pdsn16000om" ]
	 then
	     i=0;
	     unset mi
	     while (( $i < (60 / ${d_period[$j]}) ))
	     do
		((adm=i * d_period[j] + 5))
		if [ $i == 0 ]
		then
		    mi="$adm"
		else
		    mi="$mi,$adm"
		fi
        	((i=i+1))
	     done
	 fi

         if [ $fd_cron ] && [ -n $fd_cron ]
         then
            if [ "$c_optname" == "rnccfg" ]
            then
               print -u$fd_cron "$cfgrnccfg_mi $hr $dm $my $dw ksh -c \". $FLEXDAHOME/.kshrc; icf_chat.exp -i $icffname -L $tlogdir,$c_dtype.,.log,1440,40000,7\" 2>&1 >/dev/null"
               if ([ $cfgrnccfg_mi -gt 58 ])
               then
                   cfgrnccfg_mi=0
               else
                   ((cfgrnccfg_mi=cfgrnccfg_mi+1))
               fi
            elif [ "$c_optname" == "rncom" ] && [ "${d_rmt_cmprs[$j]}" == "Y" ] && [ "${d_concaton[$j]}" == "N" ]
            then
                # Configurable minute for rncom when REMOTE_COMPRESS turn on.
                # The minutes will be 5,20,35,50
                # Hour for this configuration is every 2 hour
                cfgrncom_hr=0,2,4,6,8,10,12,14,16,18,20,22
                print -u$fd_cron "$cfgrncom_mi $cfgrncom_hr $dm $my $dw ksh -c \". $FLEXDAHOME/.kshrc; icf_chat.exp -i $icffname -L $tlogdir,$c_dtype.,.log,1440,40000,7\" 2>&1 >/dev/null"
                if ([ $cfgrncom_mi -ge 50 ])
                then
                    cfgrncom_mi=5
                else
                    ((cfgrncom_mi=cfgrncom_mi+15))
                fi
            else
               print -u$fd_cron "$mi $hr $dm $my $dw ksh -c \". $FLEXDAHOME/.kshrc; icf_chat.exp -i $icffname -L $tlogdir,$c_dtype.,.log,1440,40000,7\" 2>&1 >/dev/null"
            fi
         fi

         case $c_optname in
         ppcsta )
                if [ $fd_cron ] && [ -n $fd_cron ]
                then
                    print -u$fd_cron "* * * * * ksh -c \". $FLEXDAHOME/.kshrc; sendppcsta.exp -i $disticffname -L $tlogdir/dist,$c_dtype.,.log,1440,40000,7\" 2>&1 >/dev/null"
                fi
               ;;
        esac

    ((p=p+1))
    done

((j=j+1))
done


#
# Creates FlexDA monitor configuration file
#

typeset opt=$(echo ${d_monopt[*]} |tr " " "\n" |sort -u)
typeset -lL hname=${lhost[0]}
typeset hostname=$(printf "%-s" $hname)
typeset monfname="${hostname}".mon

# SEAde66809 - Simplify the setup process when adding new network elements
fd_mon=9
create_file $fd_mon $CFGDIR/$monfname
print_nortel_mon $fd_mon "$opt" ${hostname}
# end SEAde66809 - Simplify the setup process when adding new network elements


#
# Creates OMSHOW icf, dir and cron
#

if [ ${#d_omshowinfo[*]} -gt 0 ]
then

    # Make required directories
    tlogdir=${LOGDIR}/omshow
    tdatadir=${DATADIR}/omshow

    for dir in $tlogdir $tdatadir
    do
        if [ ! -d $dir ]
        then
            echo "${cmd}: making directory $dir"
            mkdir -p $dir
        fi
    done

    typeset -l icffname=${lhost[0]}.omshow.dist.icf
    # SEAde66809 - Simplify the setup process when adding new network elements
    fd=9
	create_file $fd $CFGDIR/$icffname

	print_omshow_icf $fd $tdatadir ${DATADIR} "${d_omshowinfo[*]}" \
		${lhost[1]}
	print_thost_icf $fd ${thost[1]} ${thost[2]} ${thost[3]} ${d_tdir[$j]}
    # end SEAde66809 - Simplify the setup process when adding new network elements

    if [ $fd_cron ] && [ -n $fd_cron ]
    then
        print -u$fd_cron "* * * * * ksh -c \". $FLEXDAHOME/.kshrc; sendomshow.exp -i $icffname -L $tlogdir,omshow.,.log,1440,40000,7\" 2>&1 >/dev/null"
    fi
fi


#
# Creates Password Lookup file
#

TMFMT=`echo :Y:m:d:H:M:S | tr ":" "%"`

if [ -n "${FLEXDAPSWDFILE}" ]
then
    typeset pfname=${FLEXDAPSWDFILE}
else
    typeset pfname=${CFGDIR}/icf_pswdfile.cfg
fi

fd=8
create_file $fd $pfname
print_pswdlkup_cfg $fd
cat $pfname | uniq > $pfname.sorted
mv $pfname.sorted $pfname

hr=$P_HR
for mkt in `echo ${d_market[*]} |tr " " "\n" |sort -u |tr [:upper:] [:lower:]`
do
    chkfname=$mkt.chgpswd.chk
	# SEAde66809 - Simplify the setup process when adding new network elements
	if [ ! -f $LOGDIR/$chkfname ]
	then
		ans=1
	else
		ans=0
	fi
	# end SEAde66809 - Simplify the setup process when adding new network elements

    if [ ans -eq 1 ]
    then
		create_file 0 $chkfname
        icf_create -n $P_ENTRY -r $P_RETRY $P_PRD $LOGDIR/$chkfname
    fi

    typeset -l icffname=$mkt.chgpswd.icf
    # SEAde66809 - Simplify the setup process when adding new network elements
	fd=8
	create_file $fd $CFGDIR/$icffname
    print_chgpswd_icf $fd "$mkt"
    # end SEAde66809 - Simplify the setup process when adding new network elements

    tlogdir=$LOGDIR
    c_dtype=chgpswd

    # Add change password cron jobs
    if ([ $fd_cron ] && [ -n $fd_cron ])
    then
        print -u$fd_cron "45 $hr * * 2 ksh -c \". $FLEXDAHOME/.kshrc; icf_chat.exp -i $icffname -L $tlogdir,$mkt.$c_dtype.,.log,1440,40000,7\" 2>&1 >/dev/null"
    fi

    if ([ $hr -gt 22 ])
    then
      	hr=0
    else
      	((hr=hr+1))
    fi
    
done


#
# Add MTXOM purging facility
#

if ([ $fd_cron ] && [ -n $fd_cron ])
then
    print -u$fd_cron \
        "1,31 * * * * ksh -c \". $FLEXDAHOME/.kshrc; purge_mtxom.ksh ${lhost[1]}\" 2>&1 >/dev/null"
fi


# Add FlexDA system health check jobs

if ([ $fd_cron ] && [ -n $fd_cron ])
then
    print -u$fd_cron \
        "0,30 * * * * ksh -c \". $FLEXDAHOME/.kshrc; check_error.pl\" 2>&1 >/dev/null"
    print -u$fd_cron \
        "1,31 * * * * ksh -c \". $FLEXDAHOME/.kshrc; page_error.pl\" 2>&1 >/dev/null"
fi

cd $CFGDIR
cat ${HOST}.*.cron > ${HOST}.cron

# SEAde66809 - Simplify the setup process when adding new network elements
if [ -d $SAVEDIR ]
then
	echo "${cmd}: Files backup in ${SAVEDIR}"
fi
# end SEAde66809 - Simplify the setup process when adding new network elements

echo "${cmd}: Done!"
